package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.38.2 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.38.2) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@("`0`````````````#`!8````!````````*&``````````0```````
M`,'(``````!``#@`"0!``!L`&@````8````$`````````$``````````0```
M``````!``````````?@````````!^``````````(`````P````0````````"
M.`````````(X`````````C@`````````#P`````````/``````````$````!
M````!0```````````````````````````````````````*RH````````K*@`
M```````0``````$````&````````NZ````````"[H````````+N@````````
M!.@````````%$````````!```````@````8```````"[L````````+NP````
M````N[`````````"(`````````(@``````````@````$````!`````````)(
M`````````D@````````"2`````````!$`````````$0`````````!&1TY5``
M```$````````I6@```````"E:````````*5H`````````.P`````````[```
M```````$9'3E40````8`````````````````````````````````````````
M`````````````````````!!D=.52````!````````+N@````````NZ``````
M``"[H`````````1@````````!&```````````2]L:6(O;&0V-"YS;RXQ````
M```$````%`````-'3E4``.F=VZ0J-T7QPR>B,[ZCR`CQBGL````$````$```
M``%'3E4```````````,````"````````````````````0P````````!>````
M``````````````````````````!8````````````````````,``````````Q
M````````````````````40```````````````````"L`````````50``````
M```\`````````"D`````````5P````````!#`````````#(`````````/0``
M````````````````````````````.0``````````````````````````````
M.``````````8`````````$\`````````+``````````S`````````!<`````
M````4@````````!0````````````````````````````````````````````
M````````*@`````````>`````````"8```````````````````!.````````
M`$T```````````````````!`````````````````````/P````````!;````
M````````````````)``````````$````````````````````2@``````````
M``````````8```````````````````!:`````````#L`````````&@``````
M``!"````````````````````20````````!6`````````!D`````````-P``
M```````,`````````$0`````````/@`````````N`````````$8`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````"P`````````"````````
M````````````!0````````!,````````````````````1P`````````3````
M`````%P````````````````````````````````````````````````````(
M````````````````````#P````````!3``````````T`````````!P``````
M```<`````````!0````````````````````.````````````````````)0``
M````````````````````````````5``````````G````````````````````
M"0```````````````````"$`````````"@``````````````````````````
M````'P```````````````````"@`````````$``````````V`````````$L`
M```````````````````T`````````",`````````%0`````````2````````
M`"\`````````'0`````````@`````````$4`````````````````````````
M````````````````+0````````!=```````````````````````````````B
M``````````````````````````````!9`````````!$`````````````````
M```6````````````````````.@````````!!````````````````````2```
M```````;`````````#4`````````````````````````````````````````
M`````````````````````````````````P```!$```!$````!`````B$!$`%
M`!`0((0`AH`$``(H"`0@"0(`B8((`@"Z01"`B`````````!$````1P```$H`
M``!+````4P```%0```!5`````````%<```!8````60```%H```!;````70``
M````````']_%;BU'WLY\FG]KMIO%+GS49-0.Y/\A'%AQV0'&1^)OBP&RP.-+
MK(?7^D(L/^7"?)+CNF!LH?J;PT^9UD,):V;,KV?LU45"TW`'B>W;8C/,)8P5
M"Y<Z#9N<J7\*`J?@4)X::TG[X*,`````````````````````````````````
M``````````,```P````````>H``````````````#=A(`````````````````
M```````````"IA(`````````````````````````````C!$`````````````
M```````````````!PQ(````````````````````````````"#1(`````````
M```````````````````"C1(`````````````````````````````TA(`````
M```````````````````````"21(````````````````````````````!RA(`
M`````````````````````````````2`````````````````````````````"
MAA(`````````````````````````````9Q(`````````````````````````
M```!MA(`````````````````````````````VQ(`````````````````````
M```````"V!(````````````````````````````!A1(`````````````````
M```````````!_1(````````````````````````````!*1(`````````````
M```````````````!:A(`````````````````````````````E!(`````````
M````````````````````$"`````````````````````````````"OA(`````
M```````````````````````!(!(`````````````````````````````BA$`
M```````````````````````````!-Q(`````````````````````````````
M+"``````````````````````````````G1(`````````````````````````
M```"L!(````````````````````````````!6Q(`````````````````````
M````````X18`````````````````````````````]!(`````````````````
M```````````!?A(````````````````````````````"7!(`````````````
M```````````````!#Q(````````````````````````````"R1(`````````
M````````````````````LQ(`````````````````````````````6"(`````
M```````````````````````!UQ(````````````````````````````!L1(`
M```````````````````````````!/A(````````````````````````````!
MT1(````````````````````````````!8Q(`````````````````````````
M```!HA(````````````````````````````"F!(`````````````````````
M```````"+A(`````````````````````````````>1(`````````````````
M```````````!=Q(````````````````````````````!Z!(`````````````
M````````````````G!(`````````````````````````````RQ(`````````
M```````````````````"&1(````````````````````````````!OA(`````
M```````````````````````">A(````````````````````````````"JQ(`
M```````````````````````````!]A(````````````````````````````"
M;1$````````````````````````````!C!(`````````````````````````
M````I!(`````````````````````````````O1(`````````````````````
M```````!!!(````````````````````````````!31(`````````````````
M````````````JQ(````````````````````````````".A(`````````````
M````````````````1A(````````````````````````````!E!(`````````
M```````````````````!FQ$````````````````````````````#?Q(```X`
M``````!?0`````````#.```#U!(```X```````!6``````````;^````4Q(`
M``X````````EX`````````*````"]A(```X```````!(,``````````&```#
M%!(```X```````!=``````````(^```#^A(```X```````!(.`````````)H
M```#NA```!@```````#`B``````````````#!Q(```X```````!*H```````
M```T```#*A(```X```````!1P`````````!V```#BQ$``!````````!DV```
M```````$```#IQ(```X```````!@@`````````'````#LA(```X```````!&
M^``````````X```#SQ```!@```````#`L``````````````#Z!(```X`````
M``!4\`````````$.```$$1(```X```````!2.`````````!X```#FA```!<`
M``````#````````````````#3A(```X```````!*V`````````%4```#X1``
M`!@```````#`B``````````````$!Q$``!<```````#`@``````````(```#
MH!(```X````````H8``````````````#QA(```X```````!@$`````````!L
M```#G"```!<```````#````````````````#9!(```X```````!4P```````
M```L```#.!(```X```````!',`````````#^```#6A(```X```````!B0```
M``````)4```$&1(```X```````!,,`````````6,`%]?9VUO;E]S=&%R=%]?
M`%])5$U?9&5R96=I<W1E<E1-0VQO;F5486)L90!?251-7W)E9VES=&5R5$U#
M;&]N951A8FQE`%]?;&EB8U]S=&%R=%]M86EN`%]?8WAA7V9I;F%L:7IE`%]?
M<F5G:7-T97)?871F;W)K`%]?<W1A8VM?8VAK7V9A:6P`7U]E;G9I<F]N`'-T
M<FYC;7``;'-T870V-`!A8V-E<W,`;W!E;F1I<@!R96%D9&ER-C0`7U]S<')I
M;G1F7V-H:P!U;FQI;FL`8VQO<V5D:7(`<FUD:7(`4$Q?8W5R<F5N=%]C;VYT
M97AT`&)O;W1?1'EN84QO861E<@!097)L7VYE=UA3`%!E<FQ?;F5W6%-?9FQA
M9W,`<F5A9&QI;FL`4&5R;%]S=E]S971P=@!M96UC:'(`4&5R;%]S=E]S971P
M=FX`7U]M96UM;W9E7V-H:P!R96%L;&]C`&=E='!I9`!?7VUE;6-P>5]C:&L`
M<W1R8VAR`'-T<F1U<`!S=')T;VL`<W1R<F-H<@!M96UC<'D`<W1D97)R`%]?
M=F9P<FEN=&9?8VAK`&5X:70`;'-E96LV-`!R96%D`&=E='5I9`!S=')S='(`
M;6MD:7(`7U]E<G)N;U]L;V-A=&EO;@!?7V9P<FEN=&9?8VAK`&]P96XV-`!0
M97)L7V=V7V9E=&-H<'8`4&5R;%]G971?<W8`4&5R;%]C<F]A:U]N;V-O;G1E
M>'0`4&5R;%]M9U]S970`4&5R;%]S>7-?:6YI=#,`4&5R;%]A=&9O<FM?=6YL
M;V-K`%!E<FQ?871F;W)K7VQO8VL`4$Q?9&]?=6YD=6UP`%!E<FQ?<V%F97-Y
M<VUA;&QO8P!P97)L7W!A<G-E`'!E<FQ?9&5S=')U8W0`<&5R;%]F<F5E`%!E
M<FQ?<WES7W1E<FT`<&5R;%]A;&QO8P!P97)L7V-O;G-T<G5C=`!P97)L7W)U
M;@!L:6)P97)L+G-O`&QI8F,N<V\N-@!P87)?8W5R<F5N=%]E>&5C`'!A<E]B
M87-E;F%M90!84U]);G1E<FYA;'-?4$%27T)/3U0`<&%R7V5N=E]C;&5A;@!P
M87)?8W5R<F5N=%]E>&5C7W!R;V,`<&%R7V1I<FYA;64`<VAA7V9I;F%L`&=E
M=%]U<V5R;F%M95]F<F]M7V=E='!W=6ED`'!A<E]C;&5A;G5P`%])3U]S=&1I
M;E]U<V5D`%]?9&%T85]S=&%R=`!S:&%?=7!D871E`'AS7VEN:70`7U]B<W-?
M<W1A<G0`<VAA7VEN:70`7V5N9`!P87)?;6MT;7!D:7(`7V5D871A`'!A<E]S
M971U<%]L:6)P871H`'!A<E]F:6YD<')O9P!M>5]P87)?<&P`<&%R7V1I90!P
M87)?:6YI=%]E;G8`1TQ)0D-?,BXS-`!'3$E"0U\R+C0`1TQ)0D-?,BXS,P!'
M3$E"0U\R+C,N-`!'3$E"0U\R+C,N,@!'3$E"0U\R+C(`+W5S<B]L:6(O<&5R
M;#4O-2XS."XR+W,S.3!X+6QI;G5X+71H<F5A9"UM=6QT:2]#3U)%````````
M`@`!``(``@`!``$``@`!``(``0`"``,``@`"``$``@`!``$`!``"``$``0`"
M``(``@`!``4``0`"``$``0`"``$``0`!``(``@`"``(``0`"``(`!@`!``$`
M!@`"``8`!0`"``$``@`!``(``@`!``(``@`&``$`!``"``$`!P`"``(``0`!
M``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!``$`
M`0`!``$`!@```NP````0``````:6D;0````'```$)@```!`-:6D4````!@``
M!#$````0!I:1LP````4```0[````$`EI&70````$```$1@```!`):1ER````
M`P``!%(````0#6EI$@````(```1>`````````````+N@``````````P`````
M```I8````````+NH``````````P````````I&````````+_X``````````P`
M```````EX````````,`(``````````P```````#`"````````,`@````````
M``P```````"E1@```````,`H``````````P```````!E-````````,`X````
M``````P```````!EU````````,!```````````P```````!EV````````,!(
M``````````P```````"E.@```````,!0``````````P```````!E.@``````
M`,!8``````````P```````"E0@```````,!H``````````P```````"E*@``
M`````,!P``````````P```````"E,````````,"```````````P```````!G
MN@```````+^@````!`````H``````````````````+^H````"0````H`````
M`````````````+^P````"P````H``````````````````+^X````%@````H`
M`````````````````+_`````&P````H``````````````````+_(````'P``
M`#@``````````````````+_0````(`````H``````````````````+_8````
M(@````H``````````````````+_@````)@````H``````````````````+_H
M````.0````H``````````````````+_P````0P````H`````````````````
M`+WH`````@````L``````````````````+WP`````P````L`````````````
M`````+WX````!0````L``````````````````+X`````!@````L`````````
M`````````+X(````!P````L``````````````````+X0````"`````L`````
M`````````````+X8````"@````L``````````````````+X@````#`````L`
M`````````````````+XH````#0````L``````````````````+XP````#@``
M``L``````````````````+XX````#P````L``````````````````+Y`````
M$`````L``````````````````+Y(````$0````L``````````````````+Y0
M````$@````L``````````````````+Y8````$P````L`````````````````
M`+Y@````%`````L``````````````````+YH````%0````L`````````````
M`````+YP````%P````L``````````````````+YX````&`````L`````````
M`````````+Z`````&@````L``````````````````+Z(````'`````L`````
M`````````````+Z0````'0````L``````````````````+Z8````'@````L`
M`````````````````+Z@````(0````L``````````````````+ZH````(P``
M``L``````````````````+ZP````)`````L``````````````````+ZX````
M)0````L``````````````````+[`````)@````L``````````````````+[(
M````)P````L``````````````````+[0````*`````L`````````````````
M`+[8````*0````L``````````````````+[@````*@````L`````````````
M`````+[H````*P````L``````````````````+[P````+`````L`````````
M`````````+[X````+0````L``````````````````+\`````+@````L`````
M`````````````+\(````+P````L``````````````````+\0````,`````L`
M`````````````````+\8````,0````L``````````````````+\@````,@``
M``L``````````````````+\H````,P````L``````````````````+\P````
M-`````L``````````````````+\X````-0````L``````````````````+]`
M````-@````L``````````````````+](````-P````L`````````````````
M`+]0````.`````L``````````````````+]8````.@````L`````````````
M`````+]@````.P````L``````````````````+]H````/`````L`````````
M`````````+]P````/0````L``````````````````+]X````/@````L`````
M`````````````+^`````/P````L``````````````````+^(````0`````L`
M`````````````````+^0````00````L``````````````````+^8````0@``
M``L``````````.MO\#``)+D$`!^G^_]@XQ#P```DP,```$^.P!```%![XQ`0
M```$N0(`$:>$``,-X>-`\1``!.MO\-``!`?T``#C$/`X`"3`$```3W72!_`P
M$`CC$!`0``0'\0<`!P`'`,`0``!/=.,0$```!`?Q#1#C$!`,`!3`]/___^4`
M````P!```$]HXQ`0```$!_$-$.,0$`P`%,#T____U0```!C`$```3USC$!``
M``0'\0T0XQ`0#``4P/3____%````,,`0``!/4.,0$```!`?Q#1#C$!`,`!3`
M]/___[4```!(P!```$]$XQ`0```$!_$-$.,0$`P`%,#T____I0```&#`$```
M3SCC$!````0'\0T0XQ`0#``4P/3___^5````>,`0``!/+.,0$```!`?Q#1#C
M$!`,`!3`]/___X4```"0P!```$\@XQ`0```$!_$-$.,0$`P`%,#T____=0``
M`*C`$```3Q3C$!````0'\0T0XQ`0#``4P/3___]E````P,`0``!/".,0$```
M!`?Q#1#C$!`,`!3`]/___U4```#8P!```$[\XQ`0```$!_$-$.,0$`P`%,#T
M____10```/#`$```3O#C$!````0'\0T0XQ`0#``4P/3___\U```!",`0``!.
MY.,0$```!`?Q#1#C$!`,`!3`]/___R4```$@P!```$[8XQ`0```$!_$-$.,0
M$`P`%,#T____%0```3C`$```3LSC$!````0'\0T0XQ`0#``4P/3___\%```!
M4,`0``!.P.,0$```!`?Q#1#C$!`,`!3`]/___O4```%HP!```$ZTXQ`0```$
M!_$-$.,0$`P`%,#T___^Y0```8#`$```3JCC$!````0'\0T0XQ`0#``4P/3_
M__[5```!F,`0``!.G.,0$```!`?Q#1#C$!`,`!3`]/___L4```&PP!```$Z0
MXQ`0```$!_$-$.,0$`P`%,#T___^M0```<C`$```3H3C$!````0'\0T0XQ`0
M#``4P/3___ZE```!X,`0``!.>.,0$```!`?Q#1#C$!`,`!3`]/___I4```'X
MP!```$YLXQ`0```$!_$-$.,0$`P`%,#T___^A0```A#`$```3F#C$!````0'
M\0T0XQ`0#``4P/3___YU```"*,`0``!.5.,0$```!`?Q#1#C$!`,`!3`]/__
M_F4```)`P!```$Y(XQ`0```$!_$-$.,0$`P`%,#T___^50```EC`$```3CSC
M$!````0'\0T0XQ`0#``4P/3___Y%```"<,`0``!.,.,0$```!`?Q#1#C$!`,
M`!3`]/___C4```*(P!```$XDXQ`0```$!_$-$.,0$`P`%,#T___^)0```J#`
M$```3ACC$!````0'\0T0XQ`0#``4P/3___X5```"N,`0``!.#.,0$```!`?Q
M#1#C$!`,`!3`]/___@4```+0P!```$X`XQ`0```$!_$-$.,0$`P`%,#T___]
M]0```NC`$```3?3C$!````0'\0T0XQ`0#``4P/3___WE```#`,`0``!-Z.,0
M$```!`?Q#1#C$!`,`!3`]/___=4```,8P!```$W<XQ`0```$!_$-$.,0$`P`
M%,#T___]Q0```S#`$```3=#C$!````0'\0T0XQ`0#``4P/3___VU```#2,`0
M``!-Q.,0$```!`?Q#1#C$!`,`!3`]/___:4```-@P!```$VXXQ`0```$!_$-
M$.,0$`P`%,#T___]E0```WC`$```3:SC$!````0'\0T0XQ`0#``4P/3___V%
M```#D,`0``!-H.,0$```!`?Q#1#C$!`,`!3`]/___74```.HP!```$V4XQ`0
M```$!_$-$.,0$`P`%,#T___]90```\#`$```38CC$!````0'\0T0XQ`0#``4
MP/3___U5```#V,`0``!-?.,0$```!`?Q#1#C$!`,`!3`]/___44```/PP!``
M`$UPXQ`0```$!_$-$.,0$`P`%,#T___]-0``!`C`$```363C$!````0'\0T0
MXQ`0#``4P/3___TE```$(,`0``!-6.,0$```!`?Q#1#C$!`,`!3`]/___14`
M``0XP!```$U,XQ`0```$!_$-$.,0$`P`%,#T___]!0``!%#`$```34#C$!``
M``0'\0T0XQ`0#``4P/3___SU```$:,`0``!--.,0$```!`?Q#1#C$!`,`!3`
M]/___.4```2`P!```$THXQ`0```$!_$-$.,0$`P`%,#T___\U0``!)C`$```
M31SC$!````0'\0T0XQ`0#``4P/3___S%```$L,`0``!-$.,0$```!`?Q#1#C
M$!`,`!3`]/___+4```3(P!```$T$XQ`0```$!_$-$.,0$`P`%,#T___\I0``
M!.#`$```3/CC$!````0'\0T0XQ`0#``4P/3___R5```$^,`0``!,[.,0$```
M!`?Q#1#C$!`,`!3`]/___(4```40ZV_P,``DX_#_./]QXS#PJ``DXT#PH``D
M4"#PM$%`\*!!,/"H02#PM+)/`+#KNP`@``VR3P"QT@?PP+`HP.7___^RQ$@`
M`$S#Q"@``$S8N00`-,#E```?,\08``!,V)4`$`"GA`"VP#```$S!XU`P```$
M6*#PM.R:``0`V+D4`.GC9;````3K+@`#``V6`V2*IZH``\#E___^]N,0\*@`
M!,`P```@F>,`$```!.,P(`@`).,`(```)+D$`%+$*P``3/[`0```((KC0%`8
M`"3$*```3.GC(%`0`"18D/"T[)P`Q0%^[.D``P#8[`G__P#803`0"*<H``2G
M`0`!IW0`@H@```&Y%`!"[!(``0#8Z^0``P`-N10`8>-`,```!.-.4```).L6
M``,`#>-@,`@`!.-A4```)*<J``*G.P`0IP;_X^QI``,`V+D4`):Y%`!*ZZD`
M`P`-02I0`*=I``#E2"````#`,```#<[$*```3*_`Y?___!CL*`!4`'[$*```
M3*9!8/"\P.7___WMN00`-KD$`)+`(```'PG`Y0``#$/L*`!'`'S$*```3)'`
MY?__^\K`Y?___0?5!_#`L"BG=`!9N00`*>MO\/@`!`?^P.7___RYQ"L``$QZ
M["@`3@!\P.7___TPP#```$P!XR`P```$XT*P```$D@!)?J?T_SCC,#````3C
M,%`@`"2G*``%03`0$.PN_W9@=J?T_Y3$*```3%7`Y?___"ZG]/^IP%```$Q)
MXR!0```"IX0`!\#E```;D:?T_[&Y!``VP"```!Z%P.4```OGQ"L``$PT["C_
MI`!\I_3_[:=H``2G]/]NP.7___V8IRD``<#E___](T%`\`CC,/````2G"?_P
MN8``\*?[_U#7!_``\`#K[_"@`"1!</"@IVD``*=9``#`(```2[7C("````3`
MY?___H,```<'!P<'!\`0``!+\,`@``!+[>P2``J`9,08``!+?^P8``0`?`?Q
M!_X'!P<'!P?`$```2]S`(```2]FY"0`2ZP$``P`*ZS$`/P`,N0@`,.LS``$`
M"NPX``T`?,08``!+8NP8``<`?,`@``!+P`?Q!_X'!P<'!P?KO_!8`"3`L```
M2[7C\/]@_W&5`+``IW0`%<`0``!+5^,0$````J>$``C$*```2V/`Y?___(S`
MY?___ZV2`;``Z[_P^``$!_[`]/___[@'!^MO\#``)./P_-#_<;)/`+#KNP`@
M``VR3P"Q01#PJ-('\RBP**<)``1!4"`XXT!0```$XS!0"``$ZZ0`(``,XZ`0
M```DZV,`(``,XV`0$``DP$H`````XT`0"``DP#H`````XS`0&``D05!0$*<;
M`""G!__>XS#Q$``$XX#Q&``$XQ#Q(``$XY#PJ``$XP#PL``$04#PN*>I`$"Y
M!`!QX]!````$N00`[>/@0#``@KF"`..Y@@#I[!X@OR%5[!X@/@%6XQ!`<``D
MN00`.+D$`)"Y!`"'ITL`"*>G"MCCX"````3C8"`(``3C8/"@`"3C0"`0``3C
M`"`8``3LKB"_)56YYP"4[*X@.@56N8``EKF"`)#K5@`"``SC</"P``3L5@`A
M'E;">EJ">9GL-2"_`%6Y"`!PN><PU.,0\*@`!+F``-["&EJ">9FY@@#4XQ`@
M(``(N>APC;D(`!KKK@`"``RY"``9[*X`(1Y6[)$@OP!5N>>@9;F``&FY@@!C
M[-$[OR55XU#PP``$[-D`.@56PEI:@GF9N0@`V+D(`%/L?2"_`%7LC3N_)57K
M.0`"``SLAP`Z!5;L.0`A'E;C$/"X``3"&EJ">9FY"``4N0@`%NQJ(+\`5;F"
M`*.Y"``8N>1PBNR1(+\`5>S1.[\E5;D$`*WLJ0`Z!5:Y@@"&XQ#PR``$N0@`
MA<(:6H)YF;D(`(JYZ&!1ZZ<``@`,[&,@OP!5[*<`(1Y6['@@OP!5[(@[OR55
M[(<`.@56N8(`.N/0\-``!+F``#G"VEJ">9FY@@`VN0@`-;GH8%VY"``X[&H@
MOP!5ZXD``@`,[(D`(1Y6[),@OP!5N8(`J.PS.[\E5;GD<!KCT/#8``2Y@@`6
MPMI:@GF9N0@`%;D$`*.YZ&!=[*D`.@56[&@@OP!5N0@`&NLW``(`#.PW`"$>
M5KF"`(/L<2"_`%7LH3N_)56YY)`8N00`BNR'`#H%5KF"`!;CT/#@``2Y"``5
MPMI:@GF9N0@`&+GH8%WLH3N_)57L8R"_`%7KB0`"``SLB0`A'E;LD2"_`%7L
MJ0`Z!5:Y@@`XXQ#PZ``$N8``-\(:6H)YF;F"`#:Y"``UN>A@4;D(`#KL:""_
M`%7KIP`"``SLIP`A'E:Y@@"*[',@OP!5[-,[OR55N>20.+D$`(WLAP`Z!5:Y
M@@`VXQ#P\``$N0@`-<(:6H)YF;D(`#BYZ&!1ZXD``@`,[&H@OP!5[(D`(1Y6
MN8(`J.R3(+\`5>S3.[\E5;GD<#JY!`"M[*D`.@56N8(`-N,0\/@`!+D(`#7"
M&EJ">9FY"``ZN>A@4>NG``(`#.QH(+\`5>RG`"$>5KF"`(KL<R"_`%7LTSN_
M)56YY)`XN00`C>R'`#H%5KF"`#;C$/$```2Y"``UPAI:@GF9N0@`.+GH8%'K
MB0`"``SL:B"_`%7LB0`A'E:Y@@"H[),@OP!5[-,[OR55N>1P.KD$`*WLJ0`Z
M!5:Y@@`VXQ#Q"``$N0@`-<(:6H)YF;D(`#JYZ&!1ZZ<``@`,[&@@OP!5[*<`
M(1Y6N8(`BNQS(+\`5>S3.[\E5;GDD#BY!`"-[(<`.@56N8(`-N,0\1``!+D(
M`#7"&EJ">9FY"``XN>A@4>N)``(`#.QJ(+\`5>R)`"$>5KF"`*CLDR"_`%7L
MTSN_)56YY'`ZN00`K>RI`#H%5KF"`#;C$/$8``2Y"``UPAI:@GF9N0@`.KGH
M8%'KIP`"``SL:""_`%7LIP`A'E:Y@@"*[',@OP!5[-,[OR55N>20.+D$`(WL
MAP`Z!5:Y@@`VXQ#Q(``$N0@`-<(:6H)YF;D(`#BYZ&!1ZXD``@`,[&H@OP!5
M[(D`(1Y6N8(`J.R3(+\`5>S3.[\E5;GD<#JY!`"M[*D`.@56N8(`-N,0\2@`
M!+D(`#7"&EJ">9FY"``ZN>A@4>NG``(`#.QH(+\`5>RG`"$>5KF"`(KL<R"_
M`%7LTSN_)56YY)`XN00`C>R'`#H%5KF"`#;C$/$P``2Y"``UPAI:@GF9N0@`
M.+GH8%'KB0`"``SL:B"_`%7LB0`A'E:Y@@"H[),@OP!5[-,[OR55XQ#Q.``$
MN>1P.L(:6H)YF;F"`#:Y!`"MN0@`->RI`#H%5KGH8%&Y"``Z[&@@OP!5[-,[
MOR55ZZ<``@`,[-,@.@56[*<`(1Y6P#H`````N>>@>..`\4``!+F``'G"BEJ"
M>9FY@@!VN>A@&+D(`'7K60`"``RY"`!][%D`(1Y6[)<[OR55[)<@.@56[&H@
MOP!5N>=0VNN#``(`#+F``-.Y@@#6N0@`T;D(`-FY!`"8[),`(1Y6[#T[OR55
MN>>0%>P](#H%5KF"`!?CH/%(``3C@/%0``3"JF[9ZZ'"BF[9ZZ&Y"`"FN1H`
MA;D:`*'L9R*_/E6Y"`"C[&<"(1Y6[#H[OR55N>=@&>PZ(#H%5KF"`!WL?2*_
M/E6Y&@"!['T"(1Y6N0@`@^,P\5@`!,(Z;MGKH;GG<%:Y&@`YN>>@E>P8.[\E
M5;D:`#GL&"`Z!5;CD/%@``2Y"``QPIINV>NA[-,[OR55N1H`ENS3(#H%5NQJ
M(K\^5>QJ`B$>5N.@\6@`!+GG8%?"JF[9ZZ&Y@@!8N1H`I[D:`)7L>"*_/E6Y
M"`"=['@"(1Y6[(D[OR55[(D@.@56N>=PUK/!`&CC@/%P``3"BF[9ZZ&Y&@"&
ML\T`9KF"`-.Y&@"MN0@`INQ:.[\E5>Q:(#H%5NQC(K\^5>,0\7@`!.QC`B$>
M5L(:;MGKH;GG8#>Y&@`7N8(`.>QY(K\^5;D:`(/L>0(A'E:Y"`"%N>=P5NR8
M.[\E5;F"`%KLF"`Z!5:Y&@`5XS#Q@``$N0@`&<(Z;MGKH>R:(K\^5;D:`#;L
MF@(A'E;LT3N_)56YYY!7[-$@.@56N8(`6..@\8@`!+D:`#7"JF[9ZZ&Y"``]
MN1H`I^QX(K\^5>QX`B$>5NR#.[\E5>R#(#H%5KGG<-FSP0!XXX#QD``$PHIN
MV>NAN1H`B;/-`)>Y@@#1N1H`K;D(`*GL6CN_)57L6B`Z!5;L82*_/E7L80(A
M'E;C$/&8``2YYV#7PAINV>NAN8(`T[D:`!>Y&@"-[',BOSY5N0@`A>QS`B$>
M5NPX.[\E5;GG<%;L."`Z!5:Y@@!:XY#QH``$N1H`%<*:;MGKH;D(`!.Y&@"6
M[#HBOSY5[-$[OR55[#H"(1Y6[-$@.@56N><P5^.@\:@`!+F"`%C"JF[9ZZ&Y
M&@"5N1H`I[D(`)WL>"*_/E7L>`(A'E;LB3N_)57LB2`Z!5:YYW#3L\$`:..`
M\;``!,**;MGKH;D:`(.SS0`VN8(`T;D:`*VY"`"C[%H[OR55[%H@.@56[&$B
MOSY5[&$"(1Y6XQ#QN``$N>=@U\(:;MGKH;F"`-FY&@`7N1H`C>QY(K\^5;D(
M`(7L>0(A'E;LF#N_)56YYW!6[)@@.@56N8(`6N,P\<``!+D:`!7".F[9ZZ&Y
M"``9N1H`-NR:(K\^5>S1.[\E5>R:`B$>5NS1(#H%5KGGD%?CH/'(``2Y@@!8
MPJINV>NAN1H`-;D:`*>Y"``]['@BOSY5['@"(1Y6[(,[OR55[(,@.@56N>=P
MV;/!`'CC@/'0``3"BF[9ZZ&Y&@")L\T`E[F"`-'L82*_/E6Y&@"M[&$"(1Y6
MN>=@U[F"`-.Y"`"IN1H`C>Q:.[\E5>S3(K\^5>Q:(#H%5NS3`B$>5KGGT):Y
M@@":N0@`A>,0\=@`!.PX(+\`5>Q8.[\E5<(:;MGKH>Q3`#H%5KD:`!>Y&@`9
M[)HBOSY5N0@`%>R:`B$>5N.@\>``!+GGD'W"JF[9ZZ&Y@@"'N1H`INQA(+\`
M5>P1.[\E5>P6`#H%5KD:`*CC@/'H``2Y"`"APHJ/&[S<ZQ,``@`,N1H`C>P3
M`"$>5NS1(+\`5;GDT%FSP0`H[#H[OR55[(H@OP!5N>80J;F``*:Y@0"EL\T`
M4N-P\?``!,)ZCQN\W.PX`#H%5KD(`*6Y!`!7XW#Q^``$N1H`6<)ZCQN\W.N6
M``(`#.R6`"$>5KGDT&FY@0`9N>C0U[F``!BY@0`6N0@`%;D(`*.SP0!M[#H@
MOP!5[*H[OR55[*,`.@56N0@`H>L8``(`#.P8`"$>5NS1(+\`5;GDT%GL:B"_
M`%7LBCN_)56YYA"IN8``H[F!`*6SS0!6[(8`.@56XW#R```$N0@`I;D(`*C"
M>H\;O-SK@P`"``RY!`!7[(,`(1Y6N1H`6>PZ.[\E5>R:(+\`5;F!`!BYY-"H
MN8``%KF!`!JY"``5[#D`.@56XW#R"``$N0@`,<)ZCQN\W.L6``(`#+GHT-?L
M%@`A'E;L82"_`%6YY&!8L\$`/;GF$-BY@`#9N8$`U;/-`%/L<R"_`%7L,SN_
M)57L-P`Z!5:Y"`#5N0@`T^LY``(`#.PY`"$>5KGD8).Y@0`3XZ#R$``$N8``
M%\*JCQN\W+F!`!FY!`!:N1H`6.R-(+\`5;D(`!7LW3N_)57LV``Z!5:Y"`#1
M[)T@OP!5ZQ<``@`,[!<`(1Y6XW#R&``$PGJ/&[S<N>A@9^QQ(+\`5;GD<%.Y
MYA"CL\$`=KF``*BY@0"EL\T`5^S=.[\E5>-@\B``!+D(`*7LV0`Z!5;":H\;
MO-RY"`#:N00`5NRM(+\`5;D:`%/LW3N_)57K.``"``SLV@`Z!5;L.``A'E:Y
MYC"!N>1P$[F``(FY@0"!ZQD``@`,N0@`A>P9`"$>5KD(`(WLT2"_`%6YY-!3
MN>80D^-@\B@`!+F``)K":H\;O-RY@0"5N0@`9[/!`":SS0!2['@@OP!5XV#R
M,``$N0@`E<)JCQN\W.R(.[\E5;D$`%;LAP`Z!5:Y&@!3N>B`.>N:``(`#.R:
M`"$>5KGDT*FY@0`9N8``%[F!`!JY"``5[(,@OP!5[&,[OR55XS#R.``$[&@`
M.@56PCJ/&[S<N0@`8>L7``(`#.P7`"$>5NQQ(+\`5;GD<%FYZ-#3N>80.;/!
M`&VY@``XN8$`-;/-`%;CT/)```3"VH\;O-SLIB"_`%6Y"``U[&8[OR55N00`
M7>QJ`#H%5KD:`%GCT/)(``3KF``"``S"VH\;O-SLF``A'E:YY'")N8$`&;GH
M<'VY@``:N8$`&+D(`!6Y"``VL\$`-^QC(+\`5>PS.[\E5>PV`#H%5KGH,%'K
M&@`"``SL&@`A'E;LT2"_`%6YY-!YN>80J;F``*:Y@0"GL\T`<^PU(+\`5>R%
M.[\E5;D(`*?L@P`Z!5:Y"`"HXU#R4``$['H@OP!5[(H[OR55PEJ/&[S<XZ#R
M6``$N1H`6<*JCQN\W.N6``(`#.R6`"$>5KGDT&FY@0`9N>C0VKF``!.Y@0`6
MN0@`%>R'`#H%5K/!`'VY"`"!ZQ,``@`,[!,`(1Y6[-$@OP!5N>306;GF$*FY
M@`"GN8$`I;/-`%?L:""_`%7L.#N_)56Y"`"E[#8`.@56XX#R8``$PHJ/&[S<
MN00`6+D:`%GKEP`"``SLEP`A'E:YY-!YN8$`&;F``!:Y@0`7N0@`%;D(`*/C
M@/)H``3L.B"_`%7"BH\;O-SLJCN_)57LHP`Z!5:Y"`"AZQ8``@`,[!8`(1Y6
M[&$@OP!5N>1@6>QZ(+\`5;GHT-CLBCN_)56SP0`MN>80J;F``*.Y@0"EL\T`
M4NR'`#H%5N/0\G``!+D(`*7"VH\;O-RY"`"HN00`7;D:`%GLVB"_`%7KDP`"
M``SLDP`A'E;L.CN_)56YY&")N8$`&>P]`#H%5KF``!?CH/)X``2Y@0`8PJJ/
M&[S<N0@`%;GH8%JY"``Q[&,[OR55[&,@.@56ZQ<``@`,L\$`9NP7`"$>5N-@
M\H``!.R!(+\`5;GF$'FYY("IPFJ/&[S<N1H`:;/-`):Y@`!]N8$`>KD(`'6Y
MZ)"7[%D[OR55[%D@.@56L\$`%NM]``(`#.Q]`"$>5KD$`-6SS0!1N>2`I^-@
M\H@`!,)JRF+!UKGH@(;`.@````"Y@0`7L\$`.+F``!/K@P`"``RY@0`:[(,`
M(1Y6N0@`%;/-`&.Y"``=XZ#RD``$N>>`U\*JRF+!UKF"`-FY&@"G['DBOSY5
M['D"(1Y6XY#RF``$PIK*8L'6N1H`F+/!`%JSP0`)L\T`E;D:`&WL,3N_)57L
M,2`Z!5:Y"``V[%,[OR55[%,@.@56N>=PJ+F"`*&Y&@":N0@`E;/-`%#L82*_
M/E7L80(A'E:YYV#7N8(`T^P9.[\E5;D:`%WL&2`Z!5:Y"``5[*$[OR55[*$@
M.@56L\$`*K/-`-+C@/*@``3CH/*H``3"BLIBP=;"JLIBP=:Y&@"'N1H`INQS
M(K\^5>QS`B$>5KGG<#;L:2*_/E6Y@@`Y[&D"(1Y6N1H`@[GG8%>Y"`"-N8(`
M4>R8.[\E5;D:`*7LF"`Z!5:Y"`"I[-H[OR55[-H@.@56[)$BOSY5XS#RL``$
M[)$"(1Y6PCK*8L'6N>>05KD:`#>Y@@!8N1H`-;D(`#WLTSN_)57LTR`Z!5;C
M$/*X``2SP0`=PAK*8L'6X]#RP``$N1H`%L+:RF+!UNQH(K\^5;D:`-GL:`(A
M'E:YYV")L\T`D;F"`(KL>B*_/E6Y&@`8['H"(1Y6N0@`&;GG<(;L43N_)56Y
M@@"#[%$@.@56XZ#RR``$PJK*8L'6N1H`IKD$`&WLTR*_/E6Y&@!HN0@`9>S3
M`B$>5KGGT#>Y@@`Q[%8[OR55N1H`H^Q6(#H%5KD(`*7L.CN_)57L.B`Z!5;C
M@/+0``3"BLIBP=:Y&@"'['$BOSY5['$"(1Y6XQ#RV``$N>=P7<(:RF+!UKF"
M`%:Y&@`=N1H`A>S6(K\^5;D(`(/LU@(A'E;L.#N_)56YY]!G[#@@.@56N8(`
M:KD:`!:Y"``3[#HBOSY5[#H"(1Y6N><P;;F"`&CL43N_)57CD/+@``3L42`Z
M!5;"FLIBP=:Y&@"7N1H`ENQH(K\^5;D(`)7L:`(A'E;LB3N_)57LB2`Z!5:Y
MYV!SL\$`2..`\O``!,**RF+!UKD:`(.SS0`TN8(`<>.@\N@`!,*JRF+!UKD:
M`*VY&@"G['$BOSY5N0@`H^QQ`B$>5NQ:.[\E5;GG<-;L6B`Z!5:Y@@#9XQ#R
M^``$N1H`C<(:RF+!UKD(`(6Y&@`6[&DBOSY5[&D"(1Y6[)@[OR55N>=@5^R8
M(#H%5KF"`%JY&@`5N0@`&>S1.[\E5>S1(#H%5NR:(K\^5>,P\P``!.R:`B$>
M5L(ZRF+!UKGGD%:Y&@`WN8(`6+D:`#6Y"``][-,[OR55[-,@.@56XZ#S"``$
ML\$`7<*JRF+!UN/0\Q``!+D:`*;"VLIBP=;L:"*_/E6Y&@#9[&@"(1Y6N>=@
MB;/-`)6Y@@"!N1H`J.R!(K\^5>R!`B$>5KGG@':Y@@!SN0@`J;D:`-?L6CN_
M)57L<R*_/E7L6B`Z!5;L<P(A'E:Y!``WXS`@(``(P#H`````XS`@(``DXQ#S
M&``$PAK*8L'6N1H`%KGH4&VYYW#8[)8@OP!5N>>@/>Q6.[\E5;D:`!/L60`Z
M!5:Y"``5[-HBOSY5ZUD``@`,[-H"(1Y6[%D`(1Y6N>?0-[D(`%2YZ`!]P%H`
M````XU`@$``DN>=@`\!Z`````.-P(!@`).QA(+\`5>.@\R``!,*JRF+!UKD(
M`.JY&@#H[($[OR55N1H`X.R&`#H%5N,0\*``!+D(`.BY"``6P.H`````X^`@
M```DP!H`````XQ`@"``DU0?S*+`HIW0`"NMO\V``!`?^N00`#:?T]0?`Y?__
M\<0'!^MO\#``)./P_V#_<>PH`%P`?,08```_Q^-P$````J>$`%.Y!`""N00`
M8^,`(```E+D$`)*5`"``IX0`3NP(``P]?D&0D`'C`)```)25`)``IW3_]AN8
MXZ!P```"IX0`'[D4`)FY!`"WN00`2;D$`#BY!``JP.7___!&["8`"0!^02F@
M`)4](`"GA``/0;"P"..@L````J=T_^FY!``JZV_PT``$!_Y!J:`!N>EP.[D$
M`"KK0P`#``I00&``ZV_PT``$!_ZGJ0``N00`*NMO\-``!`?^IY@``*?T_[\'
M!P<'ZZ_P4``DX_#^R/]QLD\`L+D$`*+KNP`@``U!,/"@LD\`L=('\3"P*,#E
M___Q;.PF`"$`?A@2ISA``%@@\+C`*P``\`#L(P`(@':E#Z``["``$V!VN00`
M*J<Y``+`Y?__\=(0$J<:__^($``?I_0`!*<8``#5!_$PL"BY%``AIW0`!NNO
M\8@`!`?^P.7___$+ZV_P,``DX_#^P/]QLD\`D.N9`"``#;)/`)'2!_$XD"CL
M*``)`'RY!`!BE0`@`*=T``O5!_$XD"BG=`"6ZV_Q<``$!_[`Y?__\=:Y!`"R
M["C_\@!\N00`*\#E___P/.PH`&8`?$&@(!.5+B`3IW0`!I4`H`&GA/_PE2X@
M$Z>$`&.G"```N00`%KD$`"JG.0``LEX`,J<4__ZY"0`ZIXD``+)>`(&G%/_^
MN0D`AAJ#IXH``KD4`(BY!``HP.7__^[;XZ#PH``DISD``KD$`**Y!`!(P%``
M`!%-P.7___%<N00`*D$P\*C`Y?__[Y7L*``-_WY8`/#`ITA``,`+``#P`.P$
M`"N`=KD$`"K`Y?__\,.Y!``JP.7___#^N00`*\#E___OV>PF_Z``?+D$`"O`
MY?__[H&Y!``FP.7__^[,I_3_>I4NH`&G=/^=E0"@`J>$_X.G]/^7N00`*L#E
M____4Z?T_]C`Y?__\%8'!P<'!P?K;_`P`"3`$```/G'C\/]8_W'CL!````3`
M4```,2S$2```/FG`,```$.^R3P"@ZZH`(``-LD\`H>,KH```!,!@```22<#E
M___P_KD$`%;E2/"@``#`0```#.;C*Z````3`,```$-_`Y?__[UWK;_#8``0'
M_@<'!P?K?_`X`"3C\/``_W'C`/_X`"#C\/]8_W'C`/"@`"#C$/"@`7&Y!`"#
M09#PH+)/`+"Y!`"BZ[L`(``-N00`.;)/`+'2!Q``L"BG20__P"```!"XP.7_
M_^[+["P`$@!^[`+__P#8&!*Y%``@03+PH)4`,`"G=``B[`8`'P!^P%```#WZ
MX^!0```$N00`2+D$`#KC+K````3`Y?__[FGC0/"@`7'5!T``L"BG=``IZW_P
MX`$$!_X8$+D4`'&Y!``IN00`1Z<Y`"_`Y?__[J'L*/_8`'RY!`!)P(```#W-
MN00`5^.0@```!+D$`#KC*;````3`Y?__[SRG]/_3P.7__^^7ZV_P,``DX_#_
M0/]QLD\`8.MF`"``#;)/`&&Y!`"RT@?PN&`HN00`HY4],`"G=``$0:`P`:<(
M``"Y!``:IXD``+D$`"NR7@"!IQ3__D$P\+2Y"0"*P.7___VJ["@`EP!\IP@`
M`*?9``"Y!``2LEX`T:<4__ZY"0#2[(T`=L!EXW#PM``4Q-@``#UBZW<``P`-
MXR"P``"4N00`2Y4`L`"G=``-I_0`\$%`0`'C($```)25`$``IX0`!>PF__<]
M?KD)`$NY%`"402B0`KD$`(?C@-````C`Y?__[5KC((```"3L*``Y`'SC,-``
M``3C`+```)#C5S````1"`%``0>"P`1AP[`8`$`!\I_0`/.,0X```D$(0L`%!
MX.`!&''L&``R`'Q"</"@N00`M94]\*!!4%`!IW3_[9(]L`"GV0``XTV@``"0
M0DVP`:?;``'L1O_Y`'S5!_"X8"BG=`"@ZV_P\``$!_ZGF0``XXF@``"00HD@
M`*>;``'LAO_Y`'RG]/_KN00`M:?T_]G$V```/.#C<-````3C$'````*GA`!X
MN00`1Z>8```8*:>:``%!0$`(XS!````"IW3_^*<J``.Y%``"ZS```P`-XS#P
MJ``DP%```#TUXQ!0```2IW0`/,#@```]+>,@\*@`!.5,X````<#E___LS.,@
M\*``).PH_ZL`?+D$`#?C4/"H``2Y%`!YZW<``P`-N00`1\#E___O9^,@\*``
M!.,@T```)%"0\+3C4/"@``2GF@`!N10`F>LY``,`#4'C4`#E2.````"G]/\A
MXS#PJ``$N00`)\#E___MAN,@\*``).,@T```).PH_W(`?+D4``GK<``#``VG
M]/_7IYD``*?T_R#E2/"H`!"GF```I_3_G<#E___N2`<'LD\`(,`0```\9NLR
M`"``#>-`$```!+)/`#'`4```+Q_C)#````3$2```/%G`,```#M_`]/__[OOK
M;_`P`"3C\/``_W'C`/_X`"#C\/``_W'C`/_X`"#C\/](_W'C`/"P`"#C$/"P
M`G&R3P"0ZYD`(``-LD\`D>.P\*\!<=('$`"0*,#E___MP\`````.V.,`\*``
M)+D$`&*G21`!ISD``KD$`"O`4```#L1!@/"NP.7__^ZMN00`*[D$`#BG21``
MP.7__^S$["0`,0!^['(``0#8N00`8KD4`'>Y!``GP.7__^P%N00`HNPH`!(`
M?+D4`+:Y!`!7N00`.+D$`$O`Y?__['5!*Z``D@`@`.,P\+`"<=4',`"0**=T
M``RY!``JZV_PZ`($!_ZGJ0``I_3_\,#E___MK`<'P/3___^`!P?K;_`P`"3C
M\/``_W'C`/_X`"#C\/ZP_W'C`/%(`"#C$/%(`7&Y!`"RN00`D[)/`'!!,/"T
MZW<`(``-P"````YBLD\`<=('$`!P*,#E___[OZ<Y`"^Y!`"BN00`*\#E___M
MANPH`!D`?,`@```.4+D$`#O`Y?___=>Y!``KXX#Q2`%QU0>``'`HIW0`[>MO
M\8`!!`?^N00`*<#E___LB,`P```./,#E___KTKD$`&+L*/_=`'Q!D/%(08#P
MN)4`8`"GA`"D[*@`#P!\IP@``+D$`#:Y!``JLET`,J<4__ZGA`"$IP@``*=)
M``"Y!`!6LEX`1:<4__ZYZ6`DXQ!/__]Q[&$`-Z!EN>E@`:<!``&GA``.E2\0
M`*=T`""2`!``XQ`?__]Q[&$`&8!DZ^```0`,E2\0`*=T`!&2`!``ZR\?__]5
MIW0`"NL`'___4N,0'_[_<:?G_^^G"```IRD``+D$`#:R7@`CIQ3__KD)`":G
M"```ITD``+D$`%NGZ0__LEX`1:<4__ZY"0!+000@`>P._VT@9<`0```-PN.P
M\*@`).,0\*``)*<Y``*Y!``IP%````XKITD0`,#E___MB+D$`#BY!``IP.7_
M_^O!["8`#0!^6&#PT*4_@`#`:P``\`#L8P`H@';`,```#9BG*0``P.7__^LL
MN00`8NPH_S<`?)4`8`"G=/]@[*@`!P!\E2Z@`*>$``FG*0`!P&````UQI_3_
MIY4`H`&GA/_?I_3_];D$`"FG.0`!P.7__^TX[";_U`!^N00`.<`@```-8,#E
M___\Z;D$`"G`Y?__ZZBG]/\/P.7__^QSZ[_P6``DISD`+^/P_V#_<;D$`++`
MY?__[0;L*``%`'Q!L"`!N00`*^N_\/@`!,#T___KB0<'!P?KG_!(`"3C\/``
M_W'C`/_X`"#C\/]8_W'C`/"@`""R3P"@XQ#PH`%QZZH`(``-LD\`H=('$`"@
M*.PH`&0`?)4`(`"GA`!?IP@``*>9``"Y!``RLEX`DZ<4__ZG"1``N0D`DNQ)
M``$`V>Q``&\@9;D$`#)!L/"@N00`*\#E___M-^-9O___<>Q;`!_`9;GIL"6G
M40`!IW0`1^M"``$`#)4O4`"G=``1D@!0`.LO7___5:=T``KK`%___U+C4%_^
M_W&G1__ON00`*Z<Y`"_`Y?__[([L*``7`'SL*P`S(&6Y!``KP.7__^L3X^#P
MH`%QU0?@`*`HIW0`+>N?\/`!!`?^XQ#PH`%QU0<0`*`HIW0`(<`@```,INN?
M\/`!!,#T___J]I4O4`"G=/_/D@!0`.-07___<>Q;_[)@9*?T_\62`"``I_3_
MSJ<I``"G]/_/P.7__^NM!P<'!^NO\%``)./P_U#_<;)/`*#KJ@`@``VR3P"A
M0;#PI-('\*B@*+D$`#O`(```#'W`Y?__^='L*``N`'SC0/"D`!3$*```.9CK
M%``#``WC$"````CC4!`(``3C4!```"3L6/_C`'SC`!`0``3C`!`(`"1!$!`(
M[`;_^`!\N00`.\`@```,4L#E___YINPF_]@`?+D$`#O`(```#$S`Y?__^9OL
M*``N`'SC$/"D`!3$6```.6+KX0`#``WCX%````CC`.`(``3C`.```"3L"/_C
M`'SC,.`0``3C,.`(`"1!X.`([#;_^`!\N00`.\`@```,(<#E___Y<.PF_]@`
M?+D$`#O`(```#!K`Y?__^67L*``N`'SC4/"D`!3$Z```.2SK10`#``WC0.``
M``CC,$`(``3C,$```"3L./_C`'SC($`0``3C($`(`"1!0$`([";_^`!\N00`
M.\`@```+[\#E___Y.NPF_]@`?+D$`#O`(```"^G`Y?__^2_L*``N`'SC,/"D
M`!3$*```./;K$P`#``WC$"````CC0!`(``3C0!```"3L2/_C`'SC`!`0``3C
M`!`(`"1!$!`([`;_^`!\N00`.\`@```+OL#E___Y!.PF_]@`?+D$`#O`(```
M"[?`Y?__^/GL*``N`'SC$/"D`!3$2```.,#K40`#``WC4$````CC`%`(``3C
M`%```"3L"/_C`'SCX%`0``3CX%`(`"1!4%`([.;_^`!\N00`.\`@```+C,#E
M___XSNPF_]@`?+D$`#O`(```"XG`Y?__^,/L*``N`'SC0/"D`!3$6```.(KK
M-``#``WC,%````CCX#`(``3CX#```"3LZ/_C`'SC(#`0``3C(#`(`"1!,#`(
M[";_^`!\N00`.\`@```+7L#E___XF.PF_]@`?+D$`#O`(```"RO`Y?__^(WL
M*``N`'SCX/"D`!3$*```.%3K'@`#``WC$"````CC,!`(``3C,!```"3L./_C
M`'SC`!`0``3C`!`(`"1!$!`([`;_^`!\N00`.\`@```+`,#E___X8NPF_]@`
M?+D$`#O`(```"R/`Y?__^%?L*``N`'SC$/"D`!3$.```.![K00`#``WC0#``
M``CC`$`(``3C`$```"3L"/_C`'SC4$`0``3C4$`(`"1!0$`([%;_^`!\N00`
M.\`@```*^,#E___X+.PF_]@`?+D$`#O`(```"O+`Y?__^"'L*``N`'SC,/"D
M`!3$2```-^CKXP`#``WCX$````CC4.`(``3C4.```"3L6/_C`'SC(.`0``3C
M(.`(`"1!X.`([";_^`!\N00`.\`@```*Q\#E___W]NPF_]@`?+D$`#O`(```
M"L'`Y?__]^OL*``N`'SC4/"D`!3$Z```-[+K%0`#``WC$.````CC(!`(``3C
M(!```"3L*/_C`'SC`!`0``3C`!`(`"1!$!`([`;_^`!\N00`.\`@```*EL#E
M___WP.PF_]@`?+D$`#O`(```"EC`Y?__][7L*``N`'SC$/"D`!3$*```-WSK
M,0`#``WC,"````CC`#`(``3C`#```"3L"/_C`'SC0#`0``3C0#`(`"1!,#`(
M[$;_^`!\N00`.\`@```*+<#E___WBNPF_]@`?+D$`#O`(```"EK`Y?__]W^Y
M!``R["@`"0!\P"````I%P.7___F@N00`.\`@```*4,#E___W;+D$`#+L*``)
M`'S`(```"D[`Y?__^8VY!``[P"````I,P.7___=9N00`,NPH`!H`?,`@```)
M[,#E___Y>M4'\*B@**=T`"/`,```"NS`(```"?[KK_$```3`]/__^6FY!``[
MP"````HPP.7___<UN00`,NPH_^4`?,`@```)]L#E___Y5J?T_]S`Y?__Z.4'
M!P<'Z[_P6``DP"````GFX_#_4/]QLD\`L$$P\*3KNP`@``VR3P"QT@?PJ+`H
MP.7___<+["@`'`!\OR$@`*>$`!?`)P```#"YA``"N0,`$.PQ/[\!5=4'\*BP
M*+D4`".G=``*Z[_Q"``$!_ZG.```I_3_\\#E___HJ`<'8`#P@&`@\(A@0/"0
M8&#PF.L_\!@`),08```VT>/P_SC_<;D$`$)!`/%HLD\`($%0\,CK,@`@``VR
M3P`QXR`0```$T@?PP#`HXU#PN``DXP#PL``DY4CPH``!Y4CPJ```05#PH*<Y
M``+`Y?__Z$"G*0#_P.7__^?[ZX_P0``DX^#P`/!QX_#P`/]QXP#_^``@N2$`
M_J<D__BY!`#^X_#_4/]QXP#PJ``@XQ#PJ!!QN00`@K)/`*"G20`"ZZH`(``-
MISD``+)/`*'2!Q``H"C`Y?__YHWLDO__`-GL"3"``%7LE`"Z`'RY"0"00;#P
MH.R4`)\`?+D$`#FY!``HITD``,#E___F=.PH`+C_?+D$`#NY!``HP$$``0`(
MP.7__^AW["@`I?]^N10`,NP\`'@'?>,3O_C_<>P;`')`9>Q!/K\`5<!0```V
M2]4'4``0`*>$`'WC$!___W'L&P!A0&7L2``M`'SL2``<`7SL2``.`GS`X```
M-C35!^``$`"GA`!FXQ`?__]QP"```#8IU0<@`!``IX0`6^,0'___<<`P```V
M'M4',``0`*>$`%#C$!___W'L&P`T0&7`0```-A#5!T``$`"GA`!"XU`?__]Q
MP.```#8%N00`%=4'X`!0`*>$`#7C$%___W'`(```-?C5!R``$`"GA``JQ`@`
M`#7PXQ!?_O]QXP!?_O\@IX0`'^,07_W_<>P;_]*@9<*4``$``,`Q__\``.R3
M_V=@9*<I___C@/"H$''5!X``H"BG=``CZX_P\!`$!_ZYZ;`AN0@`*:?T__"G
M"___P"'__P``N8$``J<+``&G]/]`P"````BWP.7___[(P"````BJP.7___["
MP.7__^=CZ^_P<``DX_#_8/]QP.7__^4ZP.7__^47["@`!@!\XR`@```$Z^_Q
M$``$!_X'!P<'ZV_P,``DX_#_0/]QLD\`H+D$`&+KJ@`@``U!,/"TLD\`H<`@
M```(A=('\+B@*,#E___U<>PH`!H`?+D$`+*5`"``IX0`$[D$`#;`Y?__Y4/L
M*``<`'S5!_"XH"BG=`!6ZV_P\``$!_[5!_"XH"BG=`!-N00`-L`@```(6^MO
M\/``!,#T___W<Z<(``"Y!``[N00`%J=)``"R7@`AIQ3__K)>`$.G%/_^N0D`
M)KD)`$M!DD`"N00`*<#E___E'..P\*@`),`````'S>,`\*``)+D$`$FY!`"R
MP%````@ZISD``L#E___GE]4'\+B@**=T``VY!``[P"````@;ZV_P\``$P/3_
M__<SP.7__^;$!P?K;_`P`"2R3P`0X_#^*/]QZS$`(``-LD\`,>,P\,@`)-('
M\=`P*,!````T]4&`\-2Y!``XTD?P^$`0T@_PX$!8T@?P\$!HXR#PP``DP"``
M``=UP.7___37["@`"0!\N00`LI4`(`"G=`*6P.7__^1KP.7__^1(["@!.0!\
MXZ`@```"IX0!,Z<(``"G*0``N00`6K)>`"6G%/_^N0D`*NNR``$`#:>[``&Y
M!``KP.7__^2:XP"@``"4N00`DI4`H`"GA`)\N00`>[D$`-*Y!`!+N00`*;F$
M`&#`4```!ZZG.0`"0:"@`<#E___G#;DA`'NY!`!+N>*@1^,`H```E+GIL%2G
M6P`"N2$`5+GB4%2YZ4`K09"0`N.R7_[_<94`H`"G=/_606#Q&,`@```'5J?T
M``FG:P`(XR!O^/\"IX0`(+D$`#C`Y?__]%ZY!`!R["C_\@!\E0`@`*>$_^W`
MY?__],+L*/_H`'ZY!``GP.7__^4ZN00`8NPF`!T`?$&0\/CC8)````*GA``5
ME0!@`*>$`*FY!``FP.7___2E["8`E`!^IYL`".-@D````J=T_^^G"```N00`
M[:<9``"R7@`>IQ3__KD)`!VGN0``N00`IK)>`+JG%/_^N0D`MAJQI[H$!+D4
M`)NY!``IP.7__^/[P`````:PX]#PL``DXP#PH``DN00`<J<Y``*Y!`!)P-``
M``<;X]#PJ``DP%````<0P.7__^9PN00`)Z<Y`<#`Y?__Y5GL)@`+_W[`Y?__
MY2-8,"``[#8!BA%^0=#Q0+D$`">Y!``]P.7__^7%&*+L)@`-`'Y80/%8IUA`
M`,!+``#P`.Q%`(2`=KD$`&?$B```,[KC</#```3`0```!O_C4'````3C((``
M``2G.0`"P.7__^61I[D``.-@\,@`!-4'\=!@**=T`ARY!``KZV_R"``$!_ZY
M!``FIYL`",#E___DBKD$`&+L*/]5`'RG]/]JIVD``*?T_V9!8/#@XR!@```"
MIX0`%;D$`#C`Y?__\X/L*``'`'R5`"``IW0`':=K``CC(&````*G=/_OIRD`
M#:=Y``VGN0`-P.7__^-<P*````9_N00`DKD$`-*G"`!3I_3^QL#E___D3KD$
M`*+L*/_@`'RG"```I^D``+D$`#*R7@#CIQ3__KD)`.+KO@`!``VGNP`!I_3^
MF5A@\5S`Y?__XN'L8O]Z8'98L/%8IR@!P,"[```!_^RR_W!@=KD$`"G`Y?__
MXQ^Y!``XN00`LL`@```&E<#E___S);D$`#+L*`$``'SC$/#```3C(!````3`
MY?__]S.Y!`!B["@`\@!\IP@``*=)``"Y!``VLEX`0Z<4__ZY"0!&[$P`'@-^
MN10`5,`0```&;N,E;_S_<;)=`!*G%/_^IW0`#^Q(`4,$?J=*__NY%`#D04Y@
M`)4O0`"GA`$XN00`.,`@```%K,#E___RX.PH`,4`?.,`(```E.P(`+\`?NP(
M`+PP?L`P```&=\`@```%E[D$`&?`Y?__]/7`Y?__Y$;`4```!IO`$```!6BY
M!`#2XU#PL``DN00`2;D$`"OC$/"@`"3CT/"H`"3`4```!C*G.0`"P.7__^4I
MI_0`-,#E___CY%@@(`"G+@`1IW0`-<#E___D&\`P```%0+D$``*GJ@`!P(``
M``9IXS#PH``DN10`VKD$`&>Y!`!)N00`*^.`\+@`).,`\*@`),!0```&"./0
M\+``)*<Y``+`Y?__Y/6Y!``KISD!P,#E___CWNPH_\?_?KD$`"?`Y?__Y*:Y
M!``[P"````3\P.7___2*N00`*\#E___\T:?T_JJY%`!#XQ#PP``$N00`9^-0
M$```!,0H```R0N-`\*``)*<Y``+`0```!6?C("````3`Y?__Y!RG]/Z+P.7_
M__ROXW#PR``$U0?QT'`HIW0`I+D$`"OK;_((``3`]/__XQ>Y!`#2I_3]M./@
M\,``!.-@X```!*?T_PNY!``FISD``,#E___D9+D$`&+L*/\^`'[`Y?__^V2Y
M!`""["3_-@!\ITD``.,PC_;_<;D$`";`Y?__X@VY!``F03#PVJ=)``;`Y?__
MY!3L)@!J!GS`,```))O5!3``\-JG=/\7XS"/SO]QITD``+D$`";`Y?__X>^Y
M!``FN00`/:=)`"C`Y?__X_;L)@!,*'S`X```!:C`4```!'6Y!`!)XU#PH``D
MN00`9[D$`"N2`/%HX^#PL``DX]#PJ``DP%````4UISD``L#E___D-*?T_TGC
M,/#```3C4#`(``*GA/[$IP@``*<9``"Y!``ELEX`$J<4__ZY"0`5[!S^M@-]
MX^%?_/]QP$````4(LET`3J<4__ZYXH!EI_3^I\#E___C2L`@```$_<#E___Z
MH`<'ZW_P.``DX_#_4/]QP*```#%>LD\`L.,0H```!.N[`"``#;)/`+'CD;``
M``1!@/"DT@?PJ+`HT@"0L9"PN00`.,`@```$&\#E___Q7>PH``<`?)4Q(`"G
MA`#2P.7___=KXR"@```$XY*P```$N00`*:=9``.G20`!P#````38P.7__^&1
MN00`DNPH`!\`?.,P(!``!.-PH```!.,P,```!,!````$Q>,GL```!,#E___A
MBN-`D!``!.,P0```!)%`,`VG=`"SXW"@```$IUD``^,GL```!*=)``'`,```
M!*O`Y?__X6"Y!`"2["@`'`!\N00`.,`@```#IL#E___Q`[D$`$+L*`"!`'SC
M$)`0``3C)[````3C,!````3`Y?__X5+CH*````2G20`!XWJP```$P#````2`
MN00`)\#E___@DL!````$@[D$`#*Y!``GP.7__^$XN00`.,`@```#;N.*L```
M!)(`@+'`Y?__\,O$*P``,1BY!`"2["@`+`!\N00`*:<Y`<#`Y?__XBSL`@`!
M`-CL#``6`7_L*``3$7ZY!`!2Q+@``##ZN00`2<`@```$8>,PL```!,#E___B
ML]4'\*BP**=T`#GK?_#H``0'_L0H```PX\#E___[E,0K```PX;D$`)+L)O_,
M`'S`(```!##`Y?__XI:5`"`!IX3_-Z?T_RSC4)`0``3$Z```,,;C(%````3C
M,.````3`Y?__\AVG]/]_XR>P```$P.7__^(9I_3_2<#E___B)`<'ZY_P2``D
MX_#_4/]QLD\`H+D$`++KJ@`@``U!,/"DLD\`H<`@```#&-('\*B@*,#E___P
M2>PH`!,`?.,0(```E.P8``T`?NP8``HP?NRX``<`?)4`L`"G=``+U0?PJ*`H
MIW0`-.N?\/@`!`?^N00`*\#E___UE*<Y`"^Y!`"2P.7__^*!["@`!0!\09`@
M`;D$`"G`Y?__X0>G20`$P#````,TP.7__^"/[";_V0!^U0?PJ*`HIW0`"KD$
M`"OKG_#X``3`]/__\+?`Y?__X;P'!^OO\'``)*<I`(#C\/]@_W'`Y?__W^#`
M,6=%(P'`#^_-JXGC,"```"3C`"`(`"3`3YBZW/[`41`R5';C0"`0`"3C4"`8
M`"3`/\/2X?#E2"`H``#C,"`@`"3E2"`P``#E3"!X``#K[_$0``0'_@<'!P?K
M;_`P`"3K%``#``VY!`"RXR`@*``$N0@`$NQ1(+\`5;D$`)3C\/]@_W'C0+`P
M``2Y!`"CN3$`(:?$``2G2P`!XU"P*``DZPD`'0`,N0@`!.,`L#``)./0L'@`
M$J=T`(5!<+`X[)P`JC]^[&G_P`#8B&``!NSF``$`V.P>'[D&5>Q1_\``V4'1
MH`#KA0`&``RGBP`![$@^OP!5IX0`*>Q(`!H!?.Q(``T"?-(_<`"@`+D$`"M!
MH*!`P.7__^08TC]P`*``N00`*T&@H$#`Y?__Y`[2/W``H`"Y!``K0:"@0,#E
M___D!.RM`"J`9.N(``(`#-(_<`"@`+D$`"O`Y?__X_;2/W``H$"Y!``KP.7_
M_^/NTC]P`*"`N00`*\#E___CYM(_<`"@P+D$`"M!H*$`P.7__^/<IX?_WJ>:
M_\")8``&&Y:Y%`"9N00`/;D$`">Y!`!)P.7__^'V4)"P>.MO\-``!`?^IX@`
M0!N-&8E!<+`XN?(PB;D$`">Y&``MN00`.KD4`&BY!`!&P.7__^';&#A:,+!X
M4#"P>.PV_^)`?AN8N00`*[D(`*:Y%`"9P.7__^.=I_3_6+D$`-JG]/_&ZW_P
M.``DN00`L^.`,"@`!..0,#``!.P8.K\]5;D4`#%!0[`XDH!``*<:``&Y!`"B
MN10``4$@L#CC\/]@_W&Y"``@[!P`GCA^I^@`0+GY$#[LX0!?@';L$___`-BY
M!``RZT$`"`#>[$@`3P!^['3__P#8&%3L!#Z_`%6GA``F[`@`&0%^[`@`#`)^
MXR`D```V&$=!,"$`U_\@`"``XR`T```VITK__]?_,``P`$$P,0#C(#0``#;7
M_S``,`!!,#$`[$@`(@%^ZR4``@#>XR`T```VU_\P`#``XR`U```VU_\Q`#$`
MXR`V```VU_\R`#(`XR`W```VU_\S`#,`03`T`*<F_^:Y%@#AQN````"@N00`
M*\#E___C"]<WL#BP.*<Y``#L.0`'8%7L.0@/8%7L.1`78%7L.1@?(%6Y!``K
M[(,`'P!5XX"P<``DP.7__^+OT@.@`+`$N00`*](#H`2P#-(#H`BP%-(#H`RP
M'-(#H!"P).M_\-@`!,#T___@9*=8`#BY^1!U[%'_S(!V[!?__P#8N00`,NMQ
M``@`WNQX`$\`?NSG__\`V!A7[`<^OP!5IX0`)NP(`!D!?NP(``P"?N,@)```
M-AA^03`A`-?_(``@`.,@-```-J=Z___7_S``,`!!,#$`XR`T```VU_\P`#``
M03`Q`.QX`"(!?NM%``(`WN,@-```-M?_,``P`.,@-0``-M?_,0`Q`.,@-@``
M-M?_,@`R`.,@-P``-M?_,P`S`$$P-`"G1O_FN18`(<8@````"*?T_VW7`#``
M,`#7`#``,``'!P<'Q%@``"VXP/3__]VQ!P<'!^MO\#``).,0\'@`!*?[_V#C
M$/```"3`P```+(GC0/$0``3K;_#0``0']``````````"``$E<R\E<P!$>6YA
M3&]A9&5R.CIB;V]T7T1Y;F%,;V%D97(`26YT97)N86QS.CI005(Z.D)/3U0`
M`"]P<F]C+W-E;&8O97AE```O<')O8R\E:2\E<P!E>&4`+@!005)?5$5-4```
M4$%27U!23T=.04U%```Z`"\`4$523#5,24(``%!%4DQ,24(`4$523#5/4%0`
M`%!%4DQ)3P``4$%27TE.251)04Q)6D5$`%!!4E]34$%73D5$`%!!4E]#3$5!
M3@!005)?1$5"54<`4$%27T-!0TA%`%!!4E]'3$]"04Q?1$5"54<``%!!4E]'
M3$]"04Q?5$U01$E2`%!!4E]435!$25(``%!!4E]'3$]"04Q?5$5-4`!005)?
M1TQ/0D%,7T-,14%.``!L<V5E:R!F86EL960``')E860@9F%I;&5D`$Q$7TQ)
M0E)!4EE?4$%42`!365-414T``"4P,G@``"5S)7,E<R5S``!P87(M```E<SH@
M8W)E871I;VX@;V8@<')I=F%T92!S=6)D:7)E8W1O<GD@)7,@9F%I;&5D("AE
M<G)N;STE:2D*```E<SH@<')I=F%T92!S=6)D:7)E8W1O<GD@)7,@:7,@=6YS
M869E("AP;&5A<V4@<F5M;W9E(&ET(&%N9"!R971R>2!Y;W5R(&]P97)A=&EO
M;BD*``!0051(``!P87)L```N<&%R``!S:&]R="!R96%D```E<R5S8V%C:&4M
M)7,E<P``)7,E<W1E;7`M)74E<P`E<R5S=&5M<"TE=2TE=25S```8`'!E<FP`
M`#``4$%2.CI086-K97(Z.E9%4E-)3TX``#$N,#8Q`%5N86)L92!T;R!C<F5A
M=&4@8V%C:&4@9&ER96-T;W)Y```E<SH@8W)E871I;VX@;V8@<')I=F%T92!C
M86-H92!S=6)D:7)E8W1O<GD@)7,@9F%I;&5D("AE<G)N;STE:2D*```M90``
M+2T``&5V86P@)V5X96,@+W5S<B]B:6XO<&5R;"`@+5,@)#`@)'LQ*R(D0")]
M)PII9B`P.R`C(&YO="!R=6YN:6YG('5N9&5R('-O;64@<VAE;&P*<&%C:V%G
M92!?7W!A<E]P;#L*;7D@*"1005)?34%'24,L("1&24Q%7V]F9G-E=%]S:7IE
M+"`D8V%C:&5?;F%M95]S:7IE*3L*0D5'24X@>PHD4$%27TU!1TE#(#T@(EQN
M4$%2+G!M7&XB.PHD1DE,15]O9F9S971?<VEZ92`](#0[("`@(R!P86-K*").
M(BD*)&-A8VAE7VYA;65?<VEZ92`](#0P.PHD4$M:25!?34%'24,@/2`B4$M<
M,#`S7#`P-"(["GT*<W5B(&9I;F1?<&%R7VUA9VEC"GL*;7D@*"1F:"D@/2!`
M7SL*;7D@)&-H=6YK7W-I>F4@/2`V-"`J(#$P,C0["FUY("1B=68["FUY("1S
M:7IE(#T@+7,@)&9H.PIM>2`D<&]S(#T@*"1S:7IE+3$I("T@*"1S:7IE+3$I
M("4@)&-H=6YK7W-I>F4[("`@("`@(R!.3U1%.B`D<&]S(&ES(&$@;75L=&EP
M;&4@;V8@)&-H=6YK7W-I>F4*=VAI;&4@*"1P;W,@/CT@,"D@>PIS965K("1F
M:"P@)'!O<RP@,#L*<F5A9"`D9F@L("1B=68L("1C:'5N:U]S:7IE("L@;&5N
M9W1H*"1005)?34%'24,I.PII9B`H*&UY("1I(#T@<FEN9&5X*"1B=68L("10
M05)?34%'24,I*2`^/2`P*2!["G)E='5R;B`D<&]S("L@)&D["GT*)'!O<R`M
M/2`D8VAU;FM?<VEZ93L*?0IR971U<FX@+3$["GT*;7D@*"1P87)?=&5M<"P@
M)'!R;V=N86UE+"!`=&UP9FEL92P@)4UO9'5L94-A8VAE*3L*14Y$('L@:68@
M*"1%3E9[4$%27T-,14%.?2D@>PIR97%U:7)E($9I;&4Z.E1E;7`["G)E<75I
M<F4@1FEL93HZ0F%S96YA;64["G)E<75I<F4@1FEL93HZ4W!E8SL*;7D@)'1O
M<&1I<B`]($9I;&4Z.D)A<V5N86UE.CID:7)N86UE*"1P87)?=&5M<"D["F]U
M=',H<7%;4F5M;W9I;F<@9FEL97,@:6X@(B1P87)?=&5M<")=*3L*1FEL93HZ
M1FEN9#HZ9FEN9&1E<'1H*'-U8B![("@@+60@*2`_(')M9&ER(#H@=6YL:6YK
M('TL("1P87)?=&5M<"D["G)M9&ER("1P87)?=&5M<#L*:68@*"UD("1P87)?
M=&5M<"`F)B`D7D\@;F4@)TU35VEN,S(G*2!["FUY("1T;7`@/2!N97<@1FEL
M93HZ5&5M<"@*5$5-4$Q!5$4@/3X@)W1M<%A86%A8)RP*1$E2(#T^($9I;&4Z
M.D)A<V5N86UE.CID:7)N86UE*"1T;W!D:7(I+`I3549&25@@/3X@)RYC;60G
M+`I53DQ)3DL@/3X@,"P**3L*;7D@)&9I;&5N86UE(#T@)'1M<"T^9FEL96YA
M;64["G!R:6YT("1T;7`@/#PB+BXN(CL*>#TQ.R!W:&EL92!;(%PD>"`M;'0@
M,3`@73L@9&\*<FT@+7)F("<D<&%R7W1E;7`G"FEF(%L@7"$@+60@)R1P87)?
M=&5M<"<@73L@=&AE;@IB<F5A:PIF:0IS;&5E<"`Q"G@]8&5X<'(@7"1X("L@
M,6`*9&]N90IR;2`G)&9I;&5N86UE)PHN+BX*8VQO<V4@)'1M<#L*8VAM;V0@
M,#<P,"P@)&9I;&5N86UE.PIM>2`D8VUD(#T@(B1F:6QE;F%M92`^+V1E=B]N
M=6QL(#(^)C$@)B(["G-Y<W1E;2@D8VUD*3L*;W5T<RAQ<5M3<&%W;F5D(&)A
M8VMG<F]U;F0@<')O8V5S<R!T;R!P97)F;W)M(&-L96%N=7`Z("1F:6QE;F%M
M95TI.PI]"GT@?0I"14=)3B!["DEN=&5R;F%L<SHZ4$%2.CI"3T]4*"D@:68@
M9&5F:6YE9"`F26YT97)N86QS.CI005(Z.D)/3U0["F5V86P@>PI?<&%R7VEN
M:71?96YV*"D["FUY("1Q=6EE="`]("$D14Y6>U!!4E]$14)51WT["FUY("5S
M>7,@/2`H"G!A=&A?<V5P("`@(#T^("@D7D\@/7X@+UY-4U=I;B\@/R`G.R<@
M.B`G.B<I+`I?97AE("`@("`@("`]/B`H)%Y/(#U^("]>*#\Z35-7:6Y\3U,R
M?&-Y9W=I;BDO(#\@)RYE>&4G(#H@)R<I+`I?9&5L:6T@("`@("`]/B`H)%Y/
M(#U^("]>35-7:6Y\3U,R+R`_("=<7"<@.B`G+R<I+`HI.PI?<V5T7W!R;V=N
M86UE*"D["F]U=',H<7%;7"1P<F]G;F%M92`]("(D<')O9VYA;64B72D["E]S
M971?<&%R7W1E;7`H*3L*;W5T<RAQ<5M<)$5.5GM005)?5$5-4'T@/2`B)$5.
M5GM005)?5$5-4'TB72D["FUY("@D<W1A<G1?<&]S+"`D<W1A<G1?;V9?1DE,
M15]S96-T:6]N*3L*34%'24,Z('L*;&]C86P@)%-)1WM?7U=!4DY?7WT@/2!S
M=6(@>WT["G5N;&5S<R`H;W!E;B!?1D@L("<\.G)A=R<L("1P<F]G;F%M92D@
M>PIO=71S*'%Q6T-A;B=T(')E860@9G)O;2!F:6QE("(D<')O9VYA;64B72D[
M("`C(&1O;B=T('5S92`D(2!H97)E(&%S(&ET(')E<75I<F5S($5R<FYO+G!M
M"FQA<W0@34%'24,["GT*;7D@)&UA9VEC7W!O<R`](&9I;F1?<&%R7VUA9VEC
M*"I?1D@I.PII9B`H)&UA9VEC7W!O<R`\(#`I('L*;W5T<RAQ<5M#86XG="!F
M:6YD(&UA9VEC('-T<FEN9R`B)%!!4E]-04=)0R(@:6X@9FEL92`B)'!R;V=N
M86UE(ETI.PIL87-T($U!1TE#.PI]"F]U=',H(D9O=6YD(%!!4B!M86=I8R!A
M="!P;W-I=&EO;B`D;6%G:6-?<&]S(BD["G-E96L@7T9(+"`D;6%G:6-?<&]S
M("T@)$9)3$5?;V9F<V5T7W-I>F4@+2!L96YG=&@H(EPP0T%#2$4B*2P@,#L*
M<F5A9"!?1D@L("1B=68L(&QE;F=T:"@B7#!#04-(12(I.PII9B`H)&)U9B!N
M92`B7#!#04-(12(@)B8@)&)U9B!N92`B7#!#3$5!3B(I('L*;W5T<R@B3F\@
M8V%C:&4@;6%R:V5R(&9O=6YD(BD["FQA<W0@34%'24,["GT*;W5T<RAQ<5M#
M86-H92!M87)K97(@(B1B=68B(&9O=6YD72D["G-E96L@7T9(+"`D;6%G:6-?
M<&]S("T@)$9)3$5?;V9F<V5T7W-I>F4L(#`["G)E860@7T9(+"`D8G5F+"`D
M1DE,15]O9F9S971?<VEZ93L*;7D@)&]F9G-E="`]('5N<&%C:R@B3B(L("1B
M=68I.PIO=71S*")/9F9S970@9G)O;2!S=&%R="!O9B!&24Q%<R!I<R`D;V9F
M<V5T(BD["G-E96L@7T9(+"`D;6%G:6-?<&]S("T@)$9)3$5?;V9F<V5T7W-I
M>F4@+2`D;V9F<V5T+"`P.PHD<W1A<G1?;V9?1DE,15]S96-T:6]N(#T@=&5L
M;"!?1D@["FUY("5R97%U:7)E7VQI<W0["G)E860@7T9(+"`D8G5F+"`T.R`@
M("`@("`@("`@("`@("`@("`@("`@("`@(",@<F5A9"!T:&4@9FER<W0@(D9)
M3$4B"G=H:6QE("@D8G5F(&5Q(")&24Q%(BD@>PIR96%D(%]&2"P@)&)U9BP@
M-#L*<F5A9"!?1D@L("1B=68L('5N<&%C:R@B3B(L("1B=68I.PIM>2`D9G5L
M;&YA;64@/2`D8G5F.PIO=71S*'%Q6U5N<&%C:VEN9R!&24Q%("(D9G5L;&YA
M;64B+BXN72D["FUY("1C<F,@/2`H("1F=6QL;F%M92`]?B!S?%XH6V$M9EQD
M77LX?2DO?'P@*2`_("0Q(#H@=6YD968["FUY("@D8F%S96YA;64L("1E>'0I
M(#T@*"1B=68@/7X@;7PH/SHN*B\I/R@N*BDH7"XN*BE\*3L*<F5A9"!?1D@L
M("1B=68L(#0["G)E860@7T9(+"`D8G5F+"!U;G!A8VLH(DXB+"`D8G5F*3L*
M:68@*&1E9FEN960H)&5X="D@86YD("1E>'0@(7X@+UPN*#\Z<&U\<&Q\:7A\
M86PI)"]I*2!["FUY("1F:6QE;F%M92`](%]S879E7V%S*"(D8W)C)&5X="(L
M("1B=68L(#`W-34I.PHD4$%2.CI(96%V>3HZ1G5L;$-A8VAE>R1F=6QL;F%M
M97T@/2`D9FEL96YA;64["B1005(Z.DAE879Y.CI&=6QL0V%C:&5[)&9I;&5N
M86UE?2`]("1F=6QL;F%M93L*?0IE;'-E('L*)$UO9'5L94-A8VAE>R1F=6QL
M;F%M97T@/2!["F)U9B`]/B`D8G5F+`IC<F,@/3X@)&-R8RP*;F%M92`]/B`D
M9G5L;&YA;64L"GT["B1R97%U:7)E7VQI<W1[)&9U;&QN86UE?2LK.PI]"G)E
M860@7T9(+"`D8G5F+"`T.PI]"FQO8V%L($!)3D,@/2`H<W5B('L*;7D@*"1S
M96QF+"`D;6]D=6QE*2`]($!?.PIR971U<FX@:68@<F5F("1M;V1U;&4@;W(@
M(21M;V1U;&4["FUY("1I;F9O(#T@)$UO9'5L94-A8VAE>R1M;V1U;&5].PIR
M971U<FX@=6YL97-S("1I;F9O.PID96QE=&4@)')E<75I<F5?;&ES='LD;6]D
M=6QE?3L*)$E.0WLD;6]D=6QE?2`]("(O;&]A9&5R+R1I;F9O+R1M;V1U;&4B
M.PII9B`H)$5.5GM005)?0TQ%04Y](&%N9"!D969I;F5D*"9)3SHZ1FEL93HZ
M;F5W*2D@>PIM>2`D9F@@/2!)3SHZ1FEL92T^;F5W7W1M<&9I;&4@;W(@9&EE
M(")#86XG="!C<F5A=&4@=&5M<"!F:6QE.B`D(2(["B1F:"T^8FEN;6]D92@I
M.PHD9F@M/G!R:6YT*"1I;F9O+3Y[8G5F?2D["B1F:"T^<V5E:R@P+"`P*3L*
M<F5T=7)N("1F:#L*?0IE;'-E('L*;7D@)&9I;&5N86UE(#T@7W-A=F5?87,H
M(B1I;F9O+3Y[8W)C?2YP;2(L("1I;F9O+3Y[8G5F?2D["B1I;F9O+3Y[9FEL
M97T@/2`D9FEL96YA;64["F]P96X@;7D@)&9H+"`G/#IR87<G+"`D9FEL96YA
M;64@;W(@9&EE('%Q6T-A;B=T(')E860@(B1F:6QE;F%M92(Z("0A73L*<F5T
M=7)N("1F:#L*?0ID:64@(D)O;W1S=')A<'!I;F<@9F%I;&5D.B!C86XG="!F
M:6YD(&UO9'5L92`D;6]D=6QE(2(["GTL($!)3D,I.PIR97%U:7)E(%A33&]A
M9&5R.PIR97%U:7)E(%!!4CHZ2&5A=GD["G)E<75I<F4@0V%R<#HZ2&5A=GD[
M"G)E<75I<F4@17AP;W)T97(Z.DAE879Y.PI005(Z.DAE879Y.CI?:6YI=%]D
M>6YA;&]A9&5R*"D["G)E<75I<F4@24\Z.D9I;&4["G=H:6QE("AM>2`D9FEL
M96YA;64@/2`H<V]R="!K97ES("5R97%U:7)E7VQI<W0I6S!=*2!["G5N;&5S
M<R`H)$E.0WLD9FEL96YA;65](&]R("1F:6QE;F%M92`]?B`O0E-$4$%.+RD@
M>PII9B`H)&9I;&5N86UE(#U^("]<+G!M8S\D+VDI('L*<F5Q=6ER92`D9FEL
M96YA;64["GT*96QS92!["F1O("1F:6QE;F%M92!U;FQE<W,@)&9I;&5N86UE
M(#U^("]S:71E8W5S=&]M:7IE7"YP;"0O.PI]"GT*9&5L971E("1R97%U:7)E
M7VQI<W1[)&9I;&5N86UE?3L*?0II9B`H)&)U9B!N92`D4$M:25!?34%'24,I
M('L*;W5T<RAQ<5M.;R!Z:7`@9F]U;F0@869T97(@1DE,12!S96-T:6]N(&EN
M(&9I;&4@(B1P<F]G;F%M92)=*3L*;&%S="!-04=)0R`["GT*)'-T87)T7W!O
M<R`]("AT96QL(%]&2"D@+2`T.R`@("`@("`@("`@("`@("`C('-T87)T(&]F
M('II<`I]"FUY($!P87)?87)G<SL*;7D@*"1O=70L("1B=6YD;&4L("1L;V=F
M:"P@)&-A8VAE7VYA;64I.PID96QE=&4@)$5.5GM005)?05!07U)%55-%?3L@
M(R!S86YI=&EZ92`H4D554T4@;6%Y(&)E(&$@<V5C=7)I='D@<')O8FQE;2D*
M:68@*"$D<W1A<G1?<&]S(&]R("@D05)'5ELP72!E<2`G+2UP87(M;W!T:6]N
M<R<@)B8@<VAI9G0I*2!["FUY("5D:7-T7V-M9"`]('%W*`IP("`@8FQI8E]T
M;U]P87(*:2`@(&EN<W1A;&Q?<&%R"G4@("!U;FEN<W1A;&Q?<&%R"G,@("!S
M:6=N7W!A<@IV("`@=F5R:69Y7W!A<@HI.PII9B`H0$%21U8@86YD("1!4D=6
M6S!=(&5Q("<M+7)E=7-E)RD@>PIS:&EF="!`05)'5CL*)$5.5GM005)?05!0
M7U)%55-%?2`]('-H:69T($!!4D=6.PI]"F5L<V4@>R`C(&YO<FUA;"!P87)L
M(&)E:&%V:6]U<@IM>2!`861D7W1O7VEN8SL*=VAI;&4@*$!!4D=6*2!["B1!
M4D=66S!=(#U^("]>+2A;04E-3T),8G%P:75S5'9=*2@N*BDO(&]R(&QA<W0[
M"FEF("@D,2!E<2`G22<I('L*<'5S:"!`861D7W1O7VEN8RP@)#(["GT*96QS
M:68@*"0Q(&5Q("=-)RD@>PIE=F%L(")U<V4@)#(B.PI]"F5L<VEF("@D,2!E
M<2`G02<I('L*=6YS:&EF="!`<&%R7V%R9W,L("0R.PI]"F5L<VEF("@D,2!E
M<2`G3R<I('L*)&]U="`]("0R.PI]"F5L<VEF("@D,2!E<2`G8B<I('L*)&)U
M;F1L92`]("=S:71E)SL*?0IE;'-I9B`H)#$@97$@)T(G*2!["B1B=6YD;&4@
M/2`G86QL)SL*?0IE;'-I9B`H)#$@97$@)W$G*2!["B1Q=6EE="`](#$["GT*
M96QS:68@*"0Q(&5Q("=,)RD@>PIO<&5N("1L;V=F:"P@(CX^(BP@)#(@;W(@
M9&EE('%Q6T-A;B=T(&]P96X@;&]G(&9I;&4@(B0R(CH@)"%=.PI]"F5L<VEF
M("@D,2!E<2`G5"<I('L*)&-A8VAE7VYA;64@/2`D,CL*?0IS:&EF="A`05)'
M5BD["FEF("AM>2`D8VUD(#T@)&1I<W1?8VUD>R0Q?2D@>PID96QE=&4@)$5.
M5GLG4$%27U1%35`G?3L*:6YI=%]I;F,H*3L*<F5Q=6ER92!005(Z.D1I<W0[
M"B9[(E!!4CHZ1&ES=#HZ)&-M9")]*"D@=6YL97-S($!!4D=6.PHF>R)005(Z
M.D1I<W0Z.B1C;60B?2@D7RD@9F]R($!!4D=6.PIE>&ET.PI]"GT*=6YS:&EF
M="!`24Y#+"!`861D7W1O7VEN8SL*?0I]"FEF("@D;W5T*2!["GL*<F5Q=6ER
M92!)3SHZ1FEL93L*<F5Q=6ER92!!<F-H:79E.CI::7`["G)E<75I<F4@1&EG
M97-T.CI32$$["GT*;7D@)'!A<B`]('-H:69T*$!!4D=6*3L*;7D@)'II<#L*
M:68@*&1E9FEN960@)'!A<BD@>PIO<&5N(&UY("1F:"P@)SPZ<F%W)RP@)'!A
M<B!O<B!D:64@<7%;0V%N)W0@9FEN9"!P87(@9FEL92`B)'!A<B(Z("0A73L*
M8FQE<W,H)&9H+"`G24\Z.D9I;&4G*3L*)'II<"`]($%R8VAI=F4Z.EII<"T^
M;F5W.PHH("1Z:7`M/G)E861&<F]M1FEL94AA;F1L92@D9F@L("1P87(I(#T]
M($%R8VAI=F4Z.EII<#HZ05I?3TLH*2`I"F]R(&1I92!Q<5M%<G)O<B!R96%D
M:6YG('II<"!A<F-H:79E("(D<&%R(ET["GT*;7D@)6UE=&%?<&%R(#T@9&\@
M>PII9B`H)'II<"!A;F0@;7D@)&UE=&$@/2`D>FEP+3YC;VYT96YT<R@G3454
M02YY;6PG*2D@>PHD;65T82`]?B!S+RXJ7G!A<CHD+R]M<SL*)&UE=&$@/7X@
M<R]>7%,N*B\O;7,["B1M971A(#U^("]>("`H6UXZ72LI.B`H+BLI)"]M9SL*
M?0I].PII9B`H9&5F:6YE9"`D<&%R*2!["F]P96X@;7D@)'!H+"`G/#IR87<G
M+"`D<&%R(&]R(&1I92!Q<5M#86XG="!R96%D('!A<B!F:6QE("(D<&%R(CH@
M)"%=.PIM>2`D8G5F.PIR96%D("1P:"P@)&)U9BP@-#L*9&EE('%Q6R(D<&%R
M(B!I<R!N;W0@82!P87(@9FEL95T@=6YL97-S("1B=68@97$@)%!+6DE07TU!
M1TE#.PIC;&]S92`D<&@["GT*0W)E871E4&%T:"@D;W5T*2`["FUY("1F:"`]
M($E/.CI&:6QE+3YN97<H"B1O=70L"DE/.CI&:6QE.CI/7T-214%4*"D@?"!)
M3SHZ1FEL93HZ3U]21%=2*"D@?"!)3SHZ1FEL93HZ3U]44E5.0R@I+`HP-S<W
M+`HI(&]R(&1I92!Q<5M#86XG="!C<F5A=&4@9FEL92`B)&]U="(Z("0A73L*
M)&9H+3YB:6YM;V1E*"D["G-E96L@7T9(+"`P+"`P.PIM>2`D;&]A9&5R.PII
M9B`H9&5F:6YE9"`D<W1A<G1?;V9?1DE,15]S96-T:6]N*2!["G)E860@7T9(
M+"`D;&]A9&5R+"`D<W1A<G1?;V9?1DE,15]S96-T:6]N.PI](&5L<V4@>PIL
M;V-A;"`D+R`]('5N9&5F.PHD;&]A9&5R(#T@/%]&2#X["GT*:68@*"$D14Y6
M>U!!4E]615)"051)37T@86YD("1L;V%D97(@/7X@+UXH/SHC(7Q<0')E;2DO
M*2!["G)E<75I<F4@4$%2.CI&:6QT97(Z.E!O9%-T<FEP.PI005(Z.D9I;'1E
M<CHZ4&]D4W1R:7`M/F%P<&QY*%PD;&]A9&5R+"`D,"D["GT*)&9H+3YP<FEN
M="@D;&]A9&5R*0IO<B!D:64@<7%;17)R;W(@=W)I=&EN9R!L;V%D97(@=&\@
M(B1O=70B.B`D(5T["FEF("@D8G5N9&QE*2!["G)E<75I<F4@4$%2.CI(96%V
M>3L*4$%2.CI(96%V>3HZ7VEN:71?9'EN86QO861E<B@I.PII;FET7VEN8R@I
M.PIR97%U:7)E7VUO9'5L97,H*3L*;7D@0&EN8R`](&=R97`@>R`A+T)31%!!
M3B\@?0IG<F5P('L**"1B=6YD;&4@;F4@)W-I=&4G*2!O<@HH)%\@;F4@)$-O
M;F9I9SHZ0V]N9FEG>V%R8VAL:6)E>'!](&%N9`HD7R!N92`D0V]N9FEG.CI#
M;VYF:6=[<')I=FQI8F5X<'TI.PI]($!)3D,["G-\+RM\+WQG+"!S?"\D?'P@
M9F]R96%C:"!`:6YC.PIM>2`E9FEL97,["B1F:6QE<WLD7WTK*R!F;W(@0$1Y
M;F%,;V%D97(Z.F1L7W-H87)E9%]O8FIE8W1S+"!V86QU97,@)4E.0SL*;7D@
M)&QI8E]E>'0@/2`D0V]N9FEG.CI#;VYF:6=[;&EB7V5X='T[("`@("`@("`@
M(R!86%@@;&EB7V5X="!V<R!D;&5X="`_"FUY("5W<FET=&5N.PIF;W)E86-H
M(&UY("1K97D@*'-O<G0@:V5Y<R`E9FEL97,I('L*;7D@*"1F:6QE+"`D;F%M
M92D["FEF("AD969I;F5D*&UY("1F8R`]("1005(Z.DAE879Y.CI&=6QL0V%C
M:&5[)&ME>7TI*2!["B@D9FEL92P@)&YA;64I(#T@*"1K97DL("1F8RD["GT*
M96QS92!["F9O<F5A8V@@;7D@)&1I<B`H0&EN8RD@>PII9B`H)&ME>2`]?B!M
M?%Y<421D:7)<12\H+BHI)'QI*2!["B@D9FEL92P@)&YA;64I(#T@*"1K97DL
M("0Q*3L*;&%S=#L*?0II9B`H)&ME>2`]?B!M?%XO;&]A9&5R+UM>+UTK+R@N
M*BDD?"D@>PII9B`H;7D@)')E9B`]("1-;V1U;&5#86-H97LD,7TI('L**"1F
M:6QE+"`D;F%M92D@/2`H)')E9BP@)#$I.PIL87-T.PI]"FEF("@M9B`B)&1I
M<B\D,2(I('L**"1F:6QE+"`D;F%M92D@/2`H(B1D:7(O)#$B+"`D,2D["FQA
M<W0["GT*?0I]"GT*;F5X="!U;FQE<W,@9&5F:6YE9"`D;F%M93L*;F5X="!I
M9B`D=W)I='1E;GLD;F%M97TK*SL*;F5X="!I9B`A<F5F*"1F:6QE*2!A;F0@
M)&9I;&4@/7X@+UPN7%$D;&EB7V5X=%Q%)"]I.PIO=71S*'-P<FEN=&8H<7%;
M4&%C:VEN9R!&24Q%("(E<R(N+BY=+"!R968@)&9I;&4@/R`D9FEL92T^>VYA
M;65](#H@)&9I;&4I*3L*;7D@)&-O;G1E;G0["FEF("AR968H)&9I;&4I*2![
M"B1C;VYT96YT(#T@)&9I;&4M/GMB=69].PI]"F5L<V4@>PIL;V-A;"`D+R`]
M('5N9&5F.PIO<&5N(&UY("1T:"P@)SPZ<F%W)RP@)&9I;&4@;W(@9&EE('%Q
M6T-A;B=T(')E860@(B1F:6QE(CH@)"%=.PHD8V]N=&5N="`](#PD=&@^.PIC
M;&]S92`D=&@["E!!4CHZ1FEL=&5R.CI0;V13=')I<"T^87!P;'DH7"1C;VYT
M96YT+"`B/&5M8F5D9&5D/B\D;F%M92(I"FEF("$D14Y6>U!!4E]615)"051)
M37T@86YD("1N86UE(#U^("]<+B@_.G!M?&EX?&%L*20O:3L*4$%2.CI&:6QT
M97(Z.E!A=&-H0V]N=&5N="T^;F5W+3YA<'!L>2A<)&-O;G1E;G0L("1F:6QE
M+"`D;F%M92D["GT*)&9H+3YP<FEN="@B1DE,12(L"G!A8VLH)TXG+"!L96YG
M=&@H)&YA;64I("L@.2DL"G-P<FEN=&8H(B4P.'@O)7,B+"!!<F-H:79E.CI:
M:7`Z.F-O;7!U=&5#4D,S,B@D8V]N=&5N="DL("1N86UE*2P*<&%C:R@G3B<L
M(&QE;F=T:"@D8V]N=&5N="DI+`HD8V]N=&5N="D*;W(@9&EE('%Q6T5R<F]R
M('=R:71I;F<@96UB961D960@1DE,12!T;R`B)&]U="(Z("0A73L*;W5T<RAQ
M<5M7<FET=&5N(&%S("(D;F%M92)=*3L*?0I]"FEF("@D>FEP*2!["B1Z:7`M
M/G=R:71E5&]&:6QE2&%N9&QE*"1F:"D@/3T@07)C:&EV93HZ6FEP.CI!6E]/
M2PIO<B!D:64@<7%;17)R;W(@=W)I=&EN9R!Z:7`@<&%R="!O9B`B)&]U=")=
M.PI]"FEF("@D;65T85]P87)[8VQE86Y]*2!["B1F:"T^<')I;G0H(EPP0TQ%
M04XB*3L*?0IE;'-E('L*:68@*"%D969I;F5D("1C86-H95]N86UE*2!["FUY
M("1C='@@/2!$:6=E<W0Z.E-(02T^;F5W*#$I.PIS965K("1F:"P@,"P@,#L*
M)&-T>"T^861D9FEL92@D9F@I.PIS965K("1F:"P@,"P@,CL*)&-A8VAE7VYA
M;64@/2`D8W1X+3YH97AD:6=E<W0["GT*)&-A8VAE7VYA;64@/2!S=6)S='(@
M)&-A8VAE7VYA;64L(#`L("1C86-H95]N86UE7W-I>F4["B1C86-H95]N86UE
M("X](")<,"(@>"`H)&-A8VAE7VYA;65?<VEZ92`M(&QE;F=T:"`D8V%C:&5?
M;F%M92D["B1F:"T^<')I;G0H)&-A8VAE7VYA;64L"B)<,$-!0TA%(BD["GT*
M;7D@)&]F9G-E="`]("1F:"T^=&5L;"`M(&QE;F=T:"@D;&]A9&5R*3L*)&9H
M+3YP<FEN="AP86-K*"=.)RP@)&]F9G-E="DL"B1005)?34%'24,I.PHD9F@M
M/F-L;W-E(&]R(&1I92!Q<5M%<G)O<B!W<FET:6YG('1R86EL97(@;V8@(B1O
M=70B.B`D(5T["F-H;6]D(#`W-34L("1O=70["F5X:70["GT*>PIL87-T('5N
M;&5S<R!D969I;F5D("1S=&%R=%]P;W,["E]F:7A?<')O9VYA;64H*3L*<F5Q
M=6ER92!005(["E!!4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L;V%D97(H*3L*>PIR
M97%U:7)E($9I;&4Z.D9I;F0["G)E<75I<F4@07)C:&EV93HZ6FEP.PI]"FUY
M("1F:"`]($E/.CI&:6QE+3YN97<[("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`C($%R8VAI=F4Z.EII<"!O<&5R871E<R!O;B!A;B!)3SHZ2&%N9&QE
M"B1F:"T^9F1O<&5N*&9I;&5N;RA?1D@I+"`G<B<I(&]R(&1I92!Q<5MF9&]P
M96XH*2!F86EL960Z("0A73L*07)C:&EV93HZ6FEP.CIS971#:'5N:U-I>F4H
M+7,@7T9(*3L*;7D@)'II<"`]($%R8VAI=F4Z.EII<"T^;F5W.PHH)'II<"T^
M<F5A9$9R;VU&:6QE2&%N9&QE*"1F:"P@)'!R;V=N86UE*2`]/2!!<F-H:79E
M.CI::7`Z.D%:7T]+*"DI"F]R(&1I92!Q<5M%<G)O<B!R96%D:6YG('II<"!A
M<F-H:79E("(D<')O9VYA;64B73L*07)C:&EV93HZ6FEP.CIS971#:'5N:U-I
M>F4H-C0@*B`Q,#(T*3L*<'5S:"!`4$%2.CI,:6)#86-H92P@)'II<#L*)%!!
M4CHZ3&EB0V%C:&5[)'!R;V=N86UE?2`]("1Z:7`["F]U=',H(D5X=')A8W1I
M;F<@>FEP+BXN(BD["FEF("AD969I;F5D("1%3E9[4$%27U1%35!]*2![(",@
M<VAO=6QD(&)E('-E="!A="!T:&ES('!O:6YT(0IF;W)E86-H(&UY("1M96UB
M97(@*"`D>FEP+3YM96UB97)S("D@>PIN97AT(&EF("1M96UB97(M/FES1&ER
M96-T;W)Y.PIM>2`D;65M8F5R7VYA;64@/2`D;65M8F5R+3YF:6QE3F%M93L*
M;F5X="!U;FQE<W,@)&UE;6)E<E]N86UE(#U^(&U["EX*+S]S:&QI8B\**#\Z
M)$-O;F9I9SHZ0V]N9FEG>V%R8VAN86UE?2\I/PHH6UXO72LI"B0*?7@["FUY
M("1E>'1R86-T7VYA;64@/2`D,3L*;7D@)&1E<W1?;F%M92`]($9I;&4Z.E-P
M96,M/F-A=&9I;&4H)$5.5GM005)?5$5-4'TL("1E>'1R86-T7VYA;64I.PII
M9B`H+68@)&1E<W1?;F%M92`F)B`M<R!?(#T]("1M96UB97(M/G5N8V]M<')E
M<W-E9%-I>F4H*2D@>PIO=71S*'%Q6U-K:7!P:6YG("(D;65M8F5R7VYA;64B
M('-I;F-E(&ET(&%L<F5A9'D@97AI<W1S(&%T("(D9&5S=%]N86UE(ETI.PI]
M(&5L<V4@>PIO=71S*'%Q6T5X=')A8W1I;F<@(B1M96UB97)?;F%M92(@=&\@
M(B1D97-T7VYA;64B+BXN72D["B@D;65M8F5R+3YE>'1R86-T5&]&:6QE3F%M
M960H)&1E<W1?;F%M92D@/3T@07)C:&EV93HZ6FEP.CI!6E]/2R@I*0IO<B!D
M:64@<7%;17)R;W(@97AT<F%C=&EN9R!Z:7`@;65M8F5R('1O("(D9&5S=%]N
M86UE(ET["F-H;6]D*#`U-34L("1D97-T7VYA;64I(&EF("1>3R!E<2`B:'!U
M>"(["GT*?0I]"GT*=6YL97-S("@D4$%2.CI,:6)#86-H97LD<')O9VYA;65]
M*2!["F1I92`\/"`B+B(@=6YL97-S($!!4D=6.PI5<V%G93H@)#`@6R`M06QI
M8BYP87(@72!;("U)9&ER(%T@6R`M36UO9'5L92!=(%L@<W)C+G!A<B!=(%L@
M<')O9W)A;2YP;"!="B0P(%L@+4)\+6(@72!;+4]O=71F:6QE72!S<F,N<&%R
M"BX*)$5.5GM005)?4%)/1TY!345](#T@)'!R;V=N86UE(#T@)#`@/2!S:&EF
M="A`05)'5BD["GT*<W5B($-R96%T95!A=&@@>PIM>2`H)&YA;64I(#T@0%\[
M"G)E<75I<F4@1FEL93HZ0F%S96YA;64["FUY("@D8F%S96YA;64L("1P871H
M+"`D97AT*2`]($9I;&4Z.D)A<V5N86UE.CIF:6QE<&%R<V4H)&YA;64L("@G
M7"XN*B<I*3L*<F5Q=6ER92!&:6QE.CI0871H.PI&:6QE.CI0871H.CIM:W!A
M=&@H)'!A=&@I('5N;&5S<R@M92`D<&%T:"D[(",@;6MP871H(&1I97,@=VET
M:"!E<G)O<@I]"G-U8B!R97%U:7)E7VUO9'5L97,@>PIR97%U:7)E(&QI8CL*
M<F5Q=6ER92!$>6YA3&]A9&5R.PIR97%U:7)E(&EN=&5G97(["G)E<75I<F4@
M<W1R:6-T.PIR97%U:7)E('=A<FYI;F=S.PIR97%U:7)E('9A<G,["G)E<75I
M<F4@0V%R<#L*<F5Q=6ER92!#87)P.CI(96%V>3L*<F5Q=6ER92!%<G)N;SL*
M<F5Q=6ER92!%>'!O<G1E<CHZ2&5A=GD["G)E<75I<F4@17AP;W)T97(["G)E
M<75I<F4@1F-N=&P["G)E<75I<F4@1FEL93HZ5&5M<#L*<F5Q=6ER92!&:6QE
M.CI3<&5C.PIR97%U:7)E(%A33&]A9&5R.PIR97%U:7)E($-O;F9I9SL*<F5Q
M=6ER92!)3SHZ2&%N9&QE.PIR97%U:7)E($E/.CI&:6QE.PIR97%U:7)E($-O
M;7!R97-S.CI:;&EB.PIR97%U:7)E($%R8VAI=F4Z.EII<#L*<F5Q=6ER92!$
M:6=E<W0Z.E-(03L*<F5Q=6ER92!005(["G)E<75I<F4@4$%2.CI(96%V>3L*
M<F5Q=6ER92!005(Z.D1I<W0["G)E<75I<F4@4$%2.CI&:6QT97(Z.E!O9%-T
M<FEP.PIR97%U:7)E(%!!4CHZ1FEL=&5R.CI0871C:$-O;G1E;G0["G)E<75I
M<F4@871T<FEB=71E<SL*979A;"![(')E<75I<F4@0W=D('T["F5V86P@>R!R
M97%U:7)E(%=I;C,R('T["F5V86P@>R!R97%U:7)E(%-C86QA<CHZ571I;"!]
M.PIE=F%L('L@<F5Q=6ER92!!<F-H:79E.CI5;GII<#HZ0G5R<W0@?3L*979A
M;"![(')E<75I<F4@5&EE.CI(87-H.CI.86UE9$-A<'1U<F4@?3L*979A;"![
M(')E<75I<F4@4&5R;$E/.R!R97%U:7)E(%!E<FQ)3SHZ<V-A;&%R('T["F5V
M86P@>R!R97%U:7)E('5T9C@@?3L*?0IS=6(@7W-E=%]P87)?=&5M<"!["FEF
M("AD969I;F5D("1%3E9[4$%27U1%35!](&%N9"`D14Y6>U!!4E]414U0?2`]
M?B`O*"XK*2\I('L*)'!A<E]T96UP(#T@)#$["G)E='5R;CL*?0IF;W)E86-H
M(&UY("1P871H("@**&UA<"`D14Y6>R1??2P@<7<H(%!!4E]435!$25(@5$U0
M1$E2(%1%35!$25(@5$5-4"!435`@*2DL"G%W*"!#.EQ<5$5-4"`O=&UP("X@
M*0HI('L*;F5X="!U;FQE<W,@9&5F:6YE9"`D<&%T:"!A;F0@+60@)'!A=&@@
M86YD("UW("1P871H.PIM>2`D=7-E<FYA;64["FUY("1P=W5I9#L*979A;"![
M*"1P=W5I9"D@/2!G971P=W5I9"@D/BD@:68@9&5F:6YE9"`D/CM].PII9B`H
M(&1E9FEN960H)E=I;C,R.CI,;V=I;DYA;64I("D@>PHD=7-E<FYA;64@/2`F
M5VEN,S(Z.DQO9VEN3F%M93L*?0IE;'-I9B`H9&5F:6YE9"`D<'=U:60I('L*
M)'5S97)N86UE(#T@)'!W=6ED.PI]"F5L<V4@>PHD=7-E<FYA;64@/2`D14Y6
M>U5315).04U%?2!\?"`D14Y6>U5315)]('Q\("=365-414TG.PI]"FUY("1S
M=&UP9&ER(#T@(B1P871H)'-Y<WM?9&5L:6U]<&%R+2(N=6YP86-K*")(*B(L
M("1U<V5R;F%M92D["FUK9&ER("1S=&UP9&ER+"`P-S4U.PIM>2`D8V%C:&5?
M9&ER.PII9B`H)$5.5GM005)?0TQ%04Y]*2!["B1C86-H95]D:7(@/2`B=&5M
M<"TD)"(["GT*96QS92!["F]P96X@;7D@)&9H+"`B/#IR87<B+"`D<')O9VYA
M;64@;W(@9&EE('%Q6T-A;B=T(')E860@(B1P<F]G;F%M92(Z("0A73L*:68@
M*"AM>2`D;6%G:6-?<&]S(#T@9FEN9%]P87)?;6%G:6,H)&9H*2D@/CT@,"D@
M>PIS965K("1F:"P@)&UA9VEC7W!O<PHM("1&24Q%7V]F9G-E=%]S:7IE"BT@
M;&5N9W1H*")<,$-!0TA%(BDL(#`["FUY("1B=68["G)E860@)&9H+"`D8G5F
M+"!L96YG=&@H(EPP0T%#2$4B*3L*:68@*"1B=68@97$@(EPP0T%#2$4B*2![
M"G-E96L@)&9H+"`D;6%G:6-?<&]S"BT@)$9)3$5?;V9F<V5T7W-I>F4*+2!L
M96YG=&@H(EPP0T%#2$4B*0HM("1C86-H95]N86UE7W-I>F4L(#`["G)E860@
M)&9H+"`D8G5F+"`D8V%C:&5?;F%M95]S:7IE.PHD8G5F(#U^(',O7#`O+V<[
M"B1C86-H95]D:7(@/2`B8V%C:&4M)&)U9B(["GT*?0IC;&]S92`D9F@["GT*
M:68@*"$D8V%C:&5?9&ER*2!["B1C86-H95]D:7(@/2`B=&5M<"TD)"(["B1%
M3E9[4$%27T-,14%.?2`](#$["GT*)'-T;7!D:7(@+CT@(B1S>7-[7V1E;&EM
M?21C86-H95]D:7(B.PIM:V1I<B`D<W1M<&1I<BP@,#<U-3L*)$5.5GM005)?
M5$5-4'T@/2`D<W1M<&1I<CL*;&%S=#L*?0HD<&%R7W1E;7`@/2`D,2!I9B`D
M14Y6>U!!4E]414U0?2!A;F0@)$5.5GM005)?5$5-4'T@/7X@+R@N*RDO.PI]
M"G-U8B!?<V%V95]A<R!["FUY("@D;F%M92P@)&-O;G1E;G1S+"`D;6]D92D@
M/2!`7SL*;7D@)&9U;&QN86UE(#T@(B1P87)?=&5M<"\D;F%M92(["G5N;&5S
M<R`H+64@)&9U;&QN86UE*2!["FUY("1T96UP;F%M92`]("(D9G5L;&YA;64N
M)"0B.PIM>2`D9F@["BAO<&5N("1F:"P@)SXZ<F%W)RP@)'1E;7!N86UE*0HF
M)B`H<')I;G0@)&9H("1C;VYT96YT<RD*)B8@*&-L;W-E("1F:"D*;W(@9&EE
M('%Q6T5R<F]R('=R:71I;F<@(B1T96UP;F%M92(Z("0A73L*8VAM;V0@)&UO
M9&4L("1T96UP;F%M92!I9B!D969I;F5D("1M;V1E.PIR96YA;64H)'1E;7!N
M86UE+"`D9G5L;&YA;64I(&]R('5N;&EN:R@D=&5M<&YA;64I.PI]"G)E='5R
M;B`D9G5L;&YA;64["GT*<W5B(%]S971?<')O9VYA;64@>PII9B`H9&5F:6YE
M9"`D14Y6>U!!4E]04D]'3D%-17T@86YD("1%3E9[4$%27U!23T=.04U%?2`]
M?B`O*"XK*2\I('L*)'!R;V=N86UE(#T@)#$["GT*)'!R;V=N86UE('Q\/2`D
M,#L*:68@*"1%3E9[4$%27U1%35!](&%N9"!I;F1E>"@D<')O9VYA;64L("1%
M3E9[4$%27U1%35!]*2`^/2`P*2!["B1P<F]G;F%M92`]('-U8G-T<B@D<')O
M9VYA;64L(')I;F1E>"@D<')O9VYA;64L("1S>7-[7V1E;&EM?2D@*R`Q*3L*
M?0II9B`H(21%3E9[4$%27U!23T=.04U%?2!O<B!I;F1E>"@D<')O9VYA;64L
M("1S>7-[7V1E;&EM?2D@/CT@,"D@>PII9B`H;W!E;B!M>2`D9F@L("<\)RP@
M)'!R;V=N86UE*2!["G)E='5R;B!I9B`M<R`D9F@["GT*:68@*"US("(D<')O
M9VYA;64D<WES>U]E>&5](BD@>PHD<')O9VYA;64@+CT@)'-Y<WM?97AE?3L*
M<F5T=7)N.PI]"GT*9F]R96%C:"!M>2`D9&ER("AS<&QI="`O7%$D<WES>W!A
M=&A?<V5P?5Q%+RP@)$5.5GM0051(?2D@>PIN97AT(&EF(&5X:7-T<R`D14Y6
M>U!!4E]414U0?2!A;F0@)&1I<B!E<2`D14Y6>U!!4E]414U0?3L*)&1I<B`]
M?B!S+UQ1)'-Y<WM?9&5L:6U]7$4D+R\["B@H)'!R;V=N86UE(#T@(B1D:7(D
M<WES>U]D96QI;7TD<')O9VYA;64D<WES>U]E>&5](BDL(&QA<W0I"FEF("US
M("(D9&ER)'-Y<WM?9&5L:6U])'!R;V=N86UE)'-Y<WM?97AE?2(["B@H)'!R
M;V=N86UE(#T@(B1D:7(D<WES>U]D96QI;7TD<')O9VYA;64B*2P@;&%S="D*
M:68@+7,@(B1D:7(D<WES>U]D96QI;7TD<')O9VYA;64B.PI]"GT*<W5B(%]F
M:7A?<')O9VYA;64@>PHD,"`]("1P<F]G;F%M92!\?#T@)$5.5GM005)?4%)/
M1TY!345].PII9B`H:6YD97@H)'!R;V=N86UE+"`D<WES>U]D96QI;7TI(#P@
M,"D@>PHD<')O9VYA;64@/2`B+B1S>7-[7V1E;&EM?21P<F]G;F%M92(["GT*
M;7D@)'!W9"`]("AD969I;F5D("9#=V0Z.F=E=&-W9"D@/R!#=V0Z.F=E=&-W
M9"@I"CH@*"AD969I;F5D("97:6XS,CHZ1V5T0W=D*2`_(%=I;C,R.CI'971#
M=V0H*2`Z(&!P=V1@*3L*8VAO;7`H)'!W9"D["B1P<F]G;F%M92`]?B!S+UXH
M/SU<+EPN/UQ1)'-Y<WM?9&5L:6U]7$4I+R1P=V0D<WES>U]D96QI;7TO.PHD
M14Y6>U!!4E]04D]'3D%-17T@/2`D<')O9VYA;64["GT*<W5B(%]P87)?:6YI
M=%]E;G8@>PII9B`H("1%3E9[4$%27TE.251)04Q)6D5$?2LK(#T](#$@*2![
M"G)E='5R;CL*?2!E;'-E('L*)$5.5GM005)?24Y)5$E!3$E:141](#T@,CL*
M?0IF;W(@*'%W*"!34$%73D5$(%1%35`@0TQ%04X@1$5"54<@0T%#2$4@4%)/
M1TY!344@*2`I('L*9&5L971E("1%3E9[(E!!4E\D7R)].PI]"F9O<B`H<7<O
M(%1-4$1)4B!414U0($-,14%.($1%0E5'("\I('L*)$5.5GLB4$%27R1?(GT@
M/2`D14Y6>R)005)?1TQ/0D%,7R1?(GT@:68@97AI<W1S("1%3E9[(E!!4E]'
M3$]"04Q?)%\B?3L*?0II9B`H)$5.5GM005)?5$5-4'TI('L*9&5L971E("1%
M3E9[4$%27T-,14%.?3L*?0I]"G-U8B!O=71S('L*<F5T=7)N(&EF("1Q=6EE
M=#L*:68@*"1L;V=F:"D@>PIP<FEN="`D;&]G9F@@(D!?7&XB.PI]"F5L<V4@
M>PIP<FEN="`B0%]<;B(["GT*?0IS=6(@:6YI=%]I;F,@>PIR97%U:7)E($-O
M;F9I9SL*<'5S:"!`24Y#+"!G<F5P(&1E9FEN960L(&UA<"`D0V]N9FEG.CI#
M;VYF:6=[)%]]+"!Q=R@*87)C:&QI8F5X<"!P<FEV;&EB97AP('-I=&5A<F-H
M97AP('-I=&5L:6)E>'`*=F5N9&]R87)C:&5X<"!V96YD;W)L:6)E>'`**3L*
M?0IP86-K86=E(&UA:6X["G)E<75I<F4@4$%2.PIU;G-H:69T($!)3D,L(%PF
M4$%2.CIF:6YD7W!A<CL*4$%2+3YI;7!O<G0H0'!A<E]A<F=S*3L*9&EE('%Q
M6W!A<BYP;#H@0V%N)W0@;W!E;B!P97)L('-C<FEP="`B)'!R;V=N86UE(CH@
M3F\@<W5C:"!F:6QE(&]R(&1I<F5C=&]R>5QN70IU;FQE<W,@+64@)'!R;V=N
M86UE.PID;R`D<')O9VYA;64["D-/4D4Z.F5X:70H)#$I(&EF("@D0"`]?B]>
M7U1+7T58251?7"@H7&0K*5PI+RD["F1I92`D0"!I9B`D0#L*?3L*)#HZ7U]%
M4E)/4B`]("1`(&EF("1`.PI]"D-/4D4Z.F5X:70H)#$I(&EF("@D.CI?7T52
M4D]2(#U^+UY?5$M?15A)5%]<*"A<9"LI7"DO*3L*9&EE("0Z.E]?15)23U(@
M:68@)#HZ7U]%4E)/4CL*,3L*7U]%3D1?7PH`55-%4@``55-%4DY!344``%1%
M35!$25(`5$U0`"]T;7````````!P97)L>'-I+F,``$-!0TA%```````````!
M&P,[````[````!S__X!X```&1/__@O@```$(__^$`````3C__YJ8```!>/__
MFW@```'8__^<"````@C__YUX```"1/__G?````*`__^>\````L#__Z&0```#
M`/__H<@```,4__^BR````UC__Z+0```#;/__I3@```.L__^E<````]C__Z;(
M```$(/__K%@```14__^LT```!(3__ZU(```$L/__KU@```3T__^OB```!13_
M_["8```%=/__MY@```7$__^YV```!@#__[JH```&A/__NQ@```:H__^\V```
M!NC__[\P```'*``````````4``````%Z4@`!>`X!&PP/H`$'#@`````4````
M'/__@>@```!"```````````````4``````%Z4@`!>`X!&PP/H`$````````\
M````'/__@L```!:6`$:&#H<-B`R)"XH*BPF,"(T'C@:/!48.T`<#%GH*S\[-
MS,O*R<C'Q@Z@`4(+````````7````%S__YD8````W`!&A@Z'#8@,B0N*"HL)
MC`B-!XX&CP5&#L`"`I@*S\[-S,O*R<C'Q@Z@`4(+7`K/SLW,R\K)R,?&#J`!
M0@M."L_.S<S+RLG(Q\8.H`%""P``````+````+S__YF8````D`!&B@J+"8P(
MC0>.!H\%1@[8`P)\"L_.S<S+R@Z@`4(+````.````.S__YGX```!:@!&A@Z'
M#8@,B0N*"HL)C`B-!XX&CP5&#N`#=@K/SLW,R\K)R,?&#J`!0@L`````.```
M`2C__YLL````=`!,A@Z'#8@,B0N*"HL)C`B-!XX&CP5&#L@"`F#/SLW,R\K)
MR,?&#J`!````````/````63__YMH```!``!&APV(#(D+B@J+"8P(C0>.!H\%
M1@Z@(4P.R"("F@K/SLW,R\K)R,<.H`%""P```````#P```&D__^<*````IX`
M1H8.APV(#(D+B@J+"8P(C0>.!H\%1@[@`@,!5@K/SLW,R\K)R,?&#J`!0@L`
M```````0```!Y/__GH@````X`````````$````'X__^>K````/X`1H8.APV(
M#(D+B@J+"8P(C0>.!H\%1@Z@(4P.H$%,#MA"`LH*S\[-S,O*R<C'Q@Z@`4(+
M````$````CS__Y]H````!@`````````\```"4/__GUP```)H`$:&#H<-B`R)
M"XH*BPF,"(T'C@:/!48.H"%,#O`C`GH*S\[-S,O*R<C'Q@Z@`4(+````*```
M`I#__Z&$````-`!*BPF,"(T'C@:/!48.P`)>S\[-S,L.H`$```````!$```"
MO/__H9````%4`$:)"XH*BPF,"(T'C@:/!48.H"%,#L@B`N8*S\[-S,O*R0Z@
M`4(+7`K/SLW,R\K)#J`!1@L````````P```#!/__HJ````6,`$:*"HL)C`B-
M!XX&CP5&#M`"`P5*"L_.S<S+R@Z@`48+````````+````SC__Z?\````=@!,
MBPF,"(T'C@:/!48.T`("5`K/SLW,RPZ@`4(+````````*````VC__ZA$````
M>`!<A@Z'#8@,B0N*"HL)C`B-!XX&CP5&#N@"``````!````#E/__J)````(0
M`$:(#(D+B@J+"8P(C0>.!H\%1@P.H($$6`T/1@[0@@0#`:0*S\[-S,O*R<@.
MH`%""P```````!P```/8__^J7````"P`1HX&CP5&#L`"7L_.#J`!````7```
M`_C__ZIL```!#@!&A@Z'#8@,B0N*"HL)C`B-!XX&CP5&#N`"`EH*S\[-S,O*
MR<C'Q@Z@`4(+6@K/SLW,R\K)R,?&#J`!1@L">@K/SLW,R\K)R,?&#J`!1@L`
M````3```!%C__ZL<```&_@!*A@Z'#8@,B0N*"HL)C`B-!XX&CP5&#O@$`P*R
M"L_.S<S+RLG(Q\8.H`%""P,"[@K/SLW,R\K)R,?&#J`!1@L````X```$J/__
ML<P```(^`$:'#8@,B0N*"HL)C`B-!XX&CP5&#M`"`P'$"L_.S<S+RLG(QPZ@
M`4(+``````!````$Y/__L]````#.`$:)"XH*BPF,"(T'C@:/!48.T`("7@K/
MSLW,R\K)#J`!0@L"5@K/SLW,R\K)#J`!1@L``````#P```4H__]Z+````H``
M1H8.APV(#(D+B@J+"8P(C0>.!H\%1@[H`@,!P`K/SLW,R\K)R,?&#J`!0@L`
M```````@```%:/__M!P```!L`$J.!H\%1@[``@):S\X.H`$````````\```%
MC/__M&@```'``$R&#H<-B`R)"XH*BPF,"(T'C@:/!5X.P`(#`3H*S\[-S,O*
MR<C'Q@Z@`4(+````````/```!<S__[7H```"5`!&APV(#(D+B@J+"8P(C0>.
M!H\%>`[``@,!.@K/SLW,R\K)R,<.H`%&"P```````````!````8,__^X````
M``P`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````I8````````"D8``````````$`````
M```"X0`````````!`````````NP`````````'0````````1H``````````P`
M```````>H``````````-````````9*@`````````&0```````+N@````````
M`!L`````````"``````````:````````NZ@`````````'``````````(````
M``````0````````"D`````!O__[U````````!Z@`````````!0```````!%8
M``````````8````````(B``````````*````````!)P`````````"P``````
M```8`````````!4````````````````````#````````O=```````````@``
M``````4H`````````!0`````````!P`````````7````````&7@`````````
M!P```````!<@``````````@````````"6``````````)`````````!@`````
M````'@`````````(`````&____L`````"````0````!O___^````````%K``
M````;____P`````````!`````&____`````````5]`````!O___Y````````
M``X`````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````+NP
M`````````````````````````````!\.````````'RX````````?3@``````
M`!]N````````'XX````````?K@```````!_.````````'^X````````@#@``
M`````"`N````````($X````````@;@```````"".````````(*X````````@
MS@```````"#N````````(0X````````A+@```````"%.````````(6X`````
M```AC@```````"&N````````(<X````````A[@```````"(.````````(BX`
M```````B3@```````")N````````(HX````````BK@```````"+.````````
M(NX````````C#@```````",N````````(TX````````C;@```````"..````
M````(ZX````````CS@```````"/N````````)`X````````D+@```````"1.
M````````)&X````````DC@```````"2N````````),X````````D[@``````
M`"4.````````)2X````````E3@```````"5N````````)8X````````EK@``
M`````"7.````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````"7@``````````````````#`"`I005(N<&T*````````````
M``````"E1@```````&4T``````````````````!EU````````&78````````
MI3H```````!E.@```````*5"``````````````````"E*@```````*4P````
M``````````````!GND=#0SH@*%-54T4@3&EN=7@I(#$S+C(N,2`R,#(T,#(P
M-B!;<F5V:7-I;VX@-C=A8S<X8V%F,S%F-V-B,S(P,C$W-V4V-#(X830V9#@R
M.6(W,&8R,UT``"YS:'-T<G1A8@`N:6YT97)P`"YN;W1E+F=N=2YB=6EL9"UI
M9``N;F]T92Y!0DDM=&%G`"YG;G4N:&%S:``N9'EN<WEM`"YD>6YS='(`+F=N
M=2YV97)S:6]N`"YG;G4N=F5R<VEO;E]R`"YR96QA+F1Y;@`N<F5L82YP;'0`
M+FEN:70`+G1E>'0`+F9I;FD`+G)O9&%T80`N96A?9G)A;65?:&1R`"YE:%]F
M<F%M90`N:6YI=%]A<G)A>0`N9FEN:5]A<G)A>0`N9'EN86UI8P`N9V]T`"YD
M871A`"YB<W,`+F-O;6UE;G0`````````````````````````````````````
M``````````````````````````````````````````````````````L````!
M``````````(````````".`````````(X``````````\`````````````````
M```!```````````````3````!P`````````"`````````D@````````"2```
M```````D````````````````````!```````````````)@````<`````````
M`@````````)L`````````FP`````````(`````````````````````0`````
M`````````#@````%``````````(````````"D`````````*0````````!1@`
M```&```````````````(``````````@````T;___]@`````````"````````
M!Z@````````'J`````````#<````!@``````````````"```````````````
M/@````L``````````@````````B(````````"(@````````(T`````<````"
M``````````@`````````&````$8````#``````````(````````16```````
M`!%8````````!)P````````````````````!``````````````!.;____P``
M```````"````````%?0````````5]`````````"\````!@``````````````
M`@`````````"````6V____X``````````@```````!:P````````%K``````
M````<`````<````!``````````@``````````````&H````$``````````(`
M```````7(````````!<@`````````E@````&```````````````(````````
M`!@```!T````!`````````!"````````&7@````````9>`````````4H````
M!@```!8`````````"``````````8````?@````$`````````!@```````!Z@
M````````'J``````````/@````````````````````0``````````````'D`
M```!``````````8````````>X````````![@````````!P``````````````
M```````$`````````"````"$`````0`````````&````````)>`````````E
MX````````#[(````````````````````"```````````````B@````$`````
M````!@```````&2H````````9*@`````````*@````````````````````0`
M`````````````)`````!``````````(```````!DV````````&38````````
M0)`````````````````````(``````````````"8`````0`````````"````
M````I6@```````"E:`````````#L````````````````````!```````````
M````I@````$``````````@```````*98````````IE@````````&4```````
M``````````````@``````````````+`````.``````````,```````"[H```
M`````+N@``````````@````````````````````(``````````@```"\````
M#P`````````#````````NZ@```````"[J``````````(````````````````
M````"``````````(````R`````8``````````P```````+NP````````N[``
M```````"(`````<```````````````@`````````$````-$````!````````
M``,```````"]T````````+W0`````````C`````````````````````(````
M``````@```#6`````0`````````#````````P`````````#```````````"(
M````````````````````"```````````````W`````@``````````P``````
M`,"(````````P(@`````````*`````````````````````@`````````````
M`.$````!`````````#```````````````````,"(`````````%8`````````
M```````````!``````````$````!`````P``````````````````````````
D``#`W@````````#J`````````````````````0``````````
